"""
Tests
"""

import pytest
from load_one_data import dump_diff

from ArWikiCats import resolve_label_ar
from ArWikiCats.legacy_bots.ma_bots2.ar_lab_bot import find_ar_label
from ArWikiCats.legacy_bots.ma_bots.ye_ts_bot import translate_general_category

fast_data_list = [
    {
        "separator": " in ",
        "category": "1450s disestablishments in arizona territory",
        "output": "انحلالات عقد 1450 في إقليم أريزونا",
    },
    {
        "separator": " in ",
        "category": "1450s disestablishments in the papal states",
        "output": "انحلالات عقد 1450 في الدولة البابوية",
    },
    {"separator": " in ", "category": "1450s crimes in california", "output": "جرائم عقد 1450 في كاليفورنيا"},
    {"separator": " in ", "category": "1450s crimes in asia", "output": "جرائم عقد 1450 في آسيا"},
    {"separator": " in ", "category": "1450s establishments in england", "output": "تأسيسات عقد 1450 في إنجلترا"},
    {"separator": " in ", "category": "may 1450 crimes in asia", "output": "جرائم مايو 1450 في آسيا"},
]

data_list_1 = {
    "13th century philosophers by nationality": "فلاسفة في القرن 13 حسب الجنسية",
    "1450s architecture in the united states": "عمارة عقد 1450 في الولايات المتحدة",
    "1450s crimes in asia": "جرائم عقد 1450 في آسيا",
    "1450s crimes in california": "جرائم عقد 1450 في كاليفورنيا",
    "1450s crimes in germany": "جرائم عقد 1450 في ألمانيا",
    "1450s crimes in hong kong": "جرائم عقد 1450 في هونغ كونغ",
    "1450s crimes in peshawar": "جرائم عقد 1450 في بيشاور",
    "1450s disasters in ireland": "كوارث عقد 1450 في أيرلندا",
    "1450s disestablishments by continent": "انحلالات عقد 1450 حسب القارة",
    "1450s disestablishments in africa": "انحلالات عقد 1450 في إفريقيا",
    "1450s disestablishments in arizona territory": "انحلالات عقد 1450 في إقليم أريزونا",
    "1450s disestablishments in british columbia": "انحلالات عقد 1450 في كولومبيا البريطانية",
    "1450s disestablishments in canada": "انحلالات عقد 1450 في كندا",
    "1450s disestablishments in cape verde": "انحلالات عقد 1450 في الرأس الأخضر",
    "1450s disestablishments in france": "انحلالات عقد 1450 في فرنسا",
    "1450s disestablishments in georgia (country)": "انحلالات عقد 1450 في جورجيا",
    "1450s disestablishments in hawaii": "انحلالات عقد 1450 في هاواي",
    "1450s disestablishments in idaho": "انحلالات عقد 1450 في أيداهو",
    "1450s disestablishments in minnesota": "انحلالات عقد 1450 في منيسوتا",
    "1450s disestablishments in nauru": "انحلالات عقد 1450 في ناورو",
    "1450s disestablishments in nebraska": "انحلالات عقد 1450 في نبراسكا",
    "1450s disestablishments in oceania": "انحلالات عقد 1450 في أوقيانوسيا",
    "1450s disestablishments in oklahoma": "انحلالات عقد 1450 في أوكلاهوما",
    "1450s disestablishments in rhode island": "انحلالات عقد 1450 في رود آيلاند",
    "1450s disestablishments in south america": "انحلالات عقد 1450 في أمريكا الجنوبية",
    "1450s disestablishments in taiwan": "انحلالات عقد 1450 في تايوان",
    "1450s disestablishments in the british empire": "انحلالات عقد 1450 في الإمبراطورية البريطانية",
    "1450s disestablishments in the netherlands": "انحلالات عقد 1450 في هولندا",
    "1450s disestablishments in the papal states": "انحلالات عقد 1450 في الدولة البابوية",
    "1450s disestablishments in tunisia": "انحلالات عقد 1450 في تونس",
    "1450s disestablishments in vermont": "انحلالات عقد 1450 في فيرمونت",
    "1450s disestablishments in west virginia": "انحلالات عقد 1450 في فرجينيا الغربية",
    "1450s establishments by country": "تأسيسات عقد 1450 حسب البلد",
    "1450s establishments in armenia": "تأسيسات عقد 1450 في أرمينيا",
    "1450s establishments in asia": "تأسيسات عقد 1450 في آسيا",
    "1450s establishments in bavaria": "تأسيسات عقد 1450 في بافاريا",
    "1450s establishments in burkina faso": "تأسيسات عقد 1450 في بوركينا فاسو",
    "1450s establishments in burma": "تأسيسات عقد 1450 في بورما",
    "1450s establishments in colorado": "تأسيسات عقد 1450 في كولورادو",
    "1450s establishments in england": "تأسيسات عقد 1450 في إنجلترا",
    "1450s establishments in france": "تأسيسات عقد 1450 في فرنسا",
    "1450s establishments in georgia (u.s. state)": "تأسيسات عقد 1450 في ولاية جورجيا",
    "1450s establishments in germany": "تأسيسات عقد 1450 في ألمانيا",
    "1450s establishments in greenland": "تأسيسات عقد 1450 في جرينلاند",
    "1450s establishments in grenada": "تأسيسات عقد 1450 في غرينادا",
    "1450s establishments in indonesia": "تأسيسات عقد 1450 في إندونيسيا",
    "1450s establishments in italy": "تأسيسات عقد 1450 في إيطاليا",
    "1450s establishments in kentucky": "تأسيسات عقد 1450 في كنتاكي",
    "1450s establishments in kiribati": "تأسيسات عقد 1450 في كيريباتي",
    "1450s establishments in malaysia": "تأسيسات عقد 1450 في ماليزيا",
    "1450s establishments in mali": "تأسيسات عقد 1450 في مالي",
    "1450s establishments in malta": "تأسيسات عقد 1450 في مالطا",
    "1450s establishments in meghalaya": "تأسيسات عقد 1450 في ميغالايا",
    "1450s establishments in montenegro": "تأسيسات عقد 1450 في الجبل الأسود",
    "1450s establishments in saint vincent and grenadines": "تأسيسات عقد 1450 في سانت فنسنت وجزر غرينادين",
    "1450s establishments in saskatchewan": "تأسيسات عقد 1450 في ساسكاتشوان",
    "1450s establishments in shanghai": "تأسيسات عقد 1450 في شانغهاي",
    "1450s establishments in sikkim": "تأسيسات عقد 1450 في سيكيم",
    "1450s establishments in slovenia": "تأسيسات عقد 1450 في سلوفينيا",
    "1450s establishments in south africa": "تأسيسات عقد 1450 في جنوب إفريقيا",
    "1450s establishments in south america": "تأسيسات عقد 1450 في أمريكا الجنوبية",
    "1450s establishments in taiwan": "تأسيسات عقد 1450 في تايوان",
    "1450s establishments in the community of madrid": "تأسيسات عقد 1450 في منطقة مدريد",
    "1450s establishments in the french colonial empire": "تأسيسات عقد 1450 في الإمبراطورية الاستعمارية الفرنسية",
    "1450s establishments in the holy roman empire": "تأسيسات عقد 1450 في الإمبراطورية الرومانية المقدسة",
    "1450s establishments in the united kingdom": "تأسيسات عقد 1450 في المملكة المتحدة",
    "1450s establishments in uttar pradesh": "تأسيسات عقد 1450 في أتر برديش",
    "1450s establishments in west virginia": "تأسيسات عقد 1450 في فرجينيا الغربية",
    "14th century establishments in bohemia": "تأسيسات القرن 14 في بوهيميا",
    "15th century establishments in poland": "تأسيسات القرن 15 في بولندا",
    "16th century architecture in romania": "عمارة القرن 16 في رومانيا",
    "17th century disestablishments in ireland": "انحلالات القرن 17 في أيرلندا",
    "17th century disestablishments in sri lanka": "انحلالات القرن 17 في سريلانكا",
    "17th century disestablishments in the dutch empire": "انحلالات القرن 17 في الإمبراطورية الهولندية",
    "19th century establishments in kingdom-of hanover": "تأسيسات القرن 19 في مملكة هانوفر",
    "19th century establishments in kingdom-of sicily": "تأسيسات القرن 19 في مملكة صقلية",
    "19th century establishments in nepal": "تأسيسات القرن 19 في نيبال",
    "19th century establishments in yukon": "تأسيسات القرن 19 في يوكون",
    "19th century male composers by nationality": "ملحنون ذكور في القرن 19 حسب الجنسية",
    "1st millennium bc establishments in the roman empire": "تأسيسات الألفية 1 ق م في الإمبراطورية الرومانية",
    "1st millennium establishments in morocco": "تأسيسات الألفية 1 في المغرب",
    "20th century chemists by nationality": "كيميائيون في القرن 20 حسب الجنسية",
    "20th century crimes in slovenia": "جرائم القرن 20 في سلوفينيا",
    "20th century disestablishments in alberta": "انحلالات القرن 20 في ألبرتا",
    "20th century governors of ottoman empire": "حكام في القرن 20 في الدولة العثمانية",
    "21st century crimes in croatia": "جرائم القرن 21 في كرواتيا",
    "21st century disestablishments in korea": "انحلالات القرن 21 في كوريا",
    "21st century disestablishments in south dakota": "انحلالات القرن 21 في داكوتا الجنوبية",
    "21st century disestablishments in wales": "انحلالات القرن 21 في ويلز",
    "21st century establishments in kosovo": "تأسيسات القرن 21 في كوسوفو",
    "2nd millennium disestablishments in hawaii": "انحلالات الألفية 2 في هاواي",
    "2nd millennium disestablishments in india": "انحلالات الألفية 2 في الهند",
    "2nd millennium disestablishments in prince edward island": "انحلالات الألفية 2 في جزيرة الأمير إدوارد",
    "2nd millennium establishments in arkansas": "تأسيسات الألفية 2 في أركنساس",
    "2nd millennium establishments in el salvador": "تأسيسات الألفية 2 في السلفادور",
    "2nd millennium establishments in lebanon": "تأسيسات الألفية 2 في لبنان",
    "2nd millennium establishments in massachusetts": "تأسيسات الألفية 2 في ماساتشوستس",
    "2nd millennium establishments in morocco": "تأسيسات الألفية 2 في المغرب",
    "2nd millennium establishments in thailand": "تأسيسات الألفية 2 في تايلاند",
    "3rd century bishops in germania": "أساقفة في القرن 3 في جرمانية",
    "3rd millennium establishments in british overseas territories": "تأسيسات الألفية 3 في أقاليم ما وراء البحار البريطانية",
    "3rd millennium establishments in south korea": "تأسيسات الألفية 3 في كوريا الجنوبية",
    "450s disestablishments in the roman empire": "انحلالات عقد 450 في الإمبراطورية الرومانية",
    "5th century bc establishments by country": "تأسيسات القرن 5 ق م حسب البلد",
    "5th century disestablishments in the byzantine empire": "انحلالات القرن 5 في الإمبراطورية البيزنطية",
    "60s establishments in the roman empire": "تأسيسات عقد 60 في الإمبراطورية الرومانية",
    "6th century disestablishments in the byzantine empire": "انحلالات القرن 6 في الإمبراطورية البيزنطية",
    "april 1450 crimes in asia": "جرائم أبريل 1450 في آسيا",
    "august 1450 crimes in asia": "جرائم أغسطس 1450 في آسيا",
    "april 1450 crimes in south america": "جرائم أبريل 1450 في أمريكا الجنوبية",
    "february 1450 crimes in asia": "جرائم فبراير 1450 في آسيا",
    "february 1450 crimes in europe": "جرائم فبراير 1450 في أوروبا",
    "december 1450 crimes in europe": "جرائم ديسمبر 1450 في أوروبا",
    "february 1450 crimes in south america": "جرائم فبراير 1450 في أمريكا الجنوبية",
    "september 1450 crimes in africa": "جرائم سبتمبر 1450 في إفريقيا",
    "september 1450 crimes in asia": "جرائم سبتمبر 1450 في آسيا",
    "september 1450 crimes in europe": "جرائم سبتمبر 1450 في أوروبا",
    "october 1450 crimes in north america": "جرائم أكتوبر 1450 في أمريكا الشمالية",
    "may 1450 crimes in asia": "جرائم مايو 1450 في آسيا",
    "may 1450 crimes in europe": "جرائم مايو 1450 في أوروبا",
    "june 1450 crimes in the united states": "جرائم يونيو 1450 في الولايات المتحدة",
    "july 1450 crimes in north america": "جرائم يوليو 1450 في أمريكا الشمالية",
    "january 1450 crimes in north america": "جرائم يناير 1450 في أمريكا الشمالية",
}


@pytest.mark.parametrize("category, expected", data_list_1.items(), ids=data_list_1.keys())
@pytest.mark.fast
def test_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("tab", fast_data_list, ids=lambda x: x["category"])
@pytest.mark.fast
def test_translate_general_category_event2_fast(tab) -> None:
    label = translate_general_category(tab["category"])
    # ---
    assert label == tab["output"]


data_list_bad = [
    ("1550s disestablishments in yugoslavia", " in ", "انحلالات عقد 1550 في يوغسلافيا"),
    ("20th century disestablishments in the united kingdom", " in ", "انحلالات القرن 20 في المملكة المتحدة"),
    ("1550s establishments in wisconsin", " in ", "تأسيسات عقد 1550 في ويسكونسن"),
    ("20th century disestablishments in sri lanka", " in ", "انحلالات القرن 20 في سريلانكا"),
    ("3rd millennium disestablishments in england", " in ", "انحلالات الألفية 3 في إنجلترا"),
    ("1550s crimes in pakistan", " in ", "جرائم عقد 1550 في باكستان"),
    ("2nd millennium establishments in rhode island", " in ", "تأسيسات الألفية 2 في رود آيلاند"),
    ("1550s establishments in chile", " in ", "تأسيسات عقد 1550 في تشيلي"),
    ("1550s disestablishments in southeast asia", " in ", "انحلالات عقد 1550 في جنوب شرق آسيا"),
    ("1550s establishments in jamaica", " in ", "تأسيسات عقد 1550 في جامايكا"),
    ("20th century disasters in afghanistan", " in ", "كوارث القرن 20 في أفغانستان"),
    ("1550s disestablishments in mississippi", " in ", "انحلالات عقد 1550 في مسيسيبي"),
    ("1550s establishments in maine", " in ", "تأسيسات عقد 1550 في مين"),
    ("1550s establishments in sweden", " in ", "تأسيسات عقد 1550 في السويد"),
    (
        "20th century disestablishments in newfoundland and labrador",
        " in ",
        "انحلالات القرن 20 في نيوفاوندلاند واللابرادور",
    ),
    (
        "20th century disestablishments in the danish colonial empire",
        " in ",
        "انحلالات القرن 20 في الإمبراطورية الاستعمارية الدنماركية",
    ),
    ("20th century establishments in french guiana", " in ", "تأسيسات القرن 20 في غويانا الفرنسية"),
    ("20th century establishments in ireland", " in ", "تأسيسات القرن 20 في أيرلندا"),
    ("20th century monarchs by country", " by ", "ملكيون في القرن 20 حسب البلد"),
    ("july 1550 crimes by continent", " by ", "جرائم يوليو 1550 حسب القارة"),
]


def test_result_only_with_event2() -> None:
    expected_result = {}
    diff_result = {}
    for tab in data_list_bad:
        category, separator, expected = tab
        result = find_ar_label(category, separator, use_event2=True)
        result2 = find_ar_label(category, separator, use_event2=False)
        if result != expected and result2 != expected:
            expected_result[category] = expected
            diff_result[category] = result

    dump_diff(diff_result, "test_result_only_with_event2")
    assert diff_result == expected_result, f"Differences found: {len(diff_result)}"



#
import pytest

from ArWikiCats import resolve_arabic_category_label

data = {
    "Category:Berlin University of Arts": "تصنيف:جامعة برلين للفنون",
    "Category:Celtic mythology in popular culture": "تصنيف:أساطير كلتية في الثقافة الشعبية",
    "Category:Ethnic groups of Dominican Republic": "تصنيف:مجموعات عرقية في جمهورية الدومينيكان",
    "Category:Russian folklore characters": "تصنيف:شخصيات فلكلورية روسية",
    "Category:Scottish popular culture": "تصنيف:ثقافة شعبية إسكتلندية",
    "Category:Scottish traditions": "تصنيف:تراث إسكتلندي",
}


@pytest.mark.parametrize("category, expected", data.items(), ids=data.keys())
@pytest.mark.fast
def test_culture_and_mythology(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.countries_names_resolvers.countries_names import resolve_by_countries_names

data_1 = {
    "university of china": "جامعة الصين",
    "politics of yemen": "سياسة اليمن",
    "military installations of yemen": "منشآت اليمن العسكرية",
    "foreign relations of yemen": "علاقات اليمن الخارجية",
    "national symbols of yemen": "رموز اليمن الوطنية",
    "university of yemen": "جامعة اليمن",
    "university of arts of yemen": "جامعة اليمن للفنون",
    "politics of venezuela": "سياسة فنزويلا",
    "politics of zambia": "سياسة زامبيا",
    "politics of zimbabwe": "سياسة زيمبابوي",
    "umayyad governors of yemen": "ولاة اليمن الأمويون",
    "angola men's international footballers": "لاعبو منتخب أنغولا لكرة القدم للرجال",
    "armenia national football team managers": "مدربو منتخب أرمينيا لكرة القدم",
    "bolivia men's international footballers": "لاعبو منتخب بوليفيا لكرة القدم للرجال",
    "bulgaria women's international footballers": "لاعبات منتخب بلغاريا لكرة القدم للسيدات",
    "chad sports templates": "قوالب تشاد الرياضية",
    "costa rica sports templates": "قوالب كوستاريكا الرياضية",
    "croatia men's international footballers": "لاعبو منتخب كرواتيا لكرة القدم للرجال",
    "cyprus women's international footballers": "لاعبات منتخب قبرص لكرة القدم للسيدات",
    "czech republic men's youth international footballers": "لاعبو منتخب التشيك لكرة القدم للشباب",
    "democratic-republic-of-congo amateur international soccer players": "لاعبو منتخب جمهورية الكونغو الديمقراطية لكرة القدم للهواة",
    "democratic-republic-of-congo men's a' international footballers": "لاعبو منتخب جمهورية الكونغو الديمقراطية لكرة القدم للرجال للمحليين",
    "guam men's international footballers": "لاعبو منتخب غوام لكرة القدم للرجال",
    "guam women's international footballers": "لاعبات منتخب غوام لكرة القدم للسيدات",
    "guinea-bissau women's international footballers": "لاعبات منتخب غينيا بيساو لكرة القدم للسيدات",
    "iceland women's youth international footballers": "لاعبات منتخب آيسلندا لكرة القدم للشابات",
    "kosovo national football team managers": "مدربو منتخب كوسوفو لكرة القدم",
    "latvia men's youth international footballers": "لاعبو منتخب لاتفيا لكرة القدم للشباب",
    "malawi men's international footballers": "لاعبو منتخب ملاوي لكرة القدم للرجال",
    "malaysia women's international footballers": "لاعبات منتخب ماليزيا لكرة القدم للسيدات",
    "mauritania sports templates": "قوالب موريتانيا الرياضية",
    "mexico women's international footballers": "لاعبات منتخب المكسيك لكرة القدم للسيدات",
    "north korea men's international footballers": "لاعبو منتخب كوريا الشمالية لكرة القدم للرجال",
    "peru men's youth international footballers": "لاعبو منتخب بيرو لكرة القدم للشباب",
    "poland men's international footballers": "لاعبو منتخب بولندا لكرة القدم للرجال",
    "san marino men's international footballers": "لاعبو منتخب سان مارينو لكرة القدم للرجال",
    "slovakia sports templates": "قوالب سلوفاكيا الرياضية",
    "switzerland men's youth international footballers": "لاعبو منتخب سويسرا لكرة القدم للشباب",
    "tanzania sports templates": "قوالب تنزانيا الرياضية",
    "trinidad and tobago national football team managers": "مدربو منتخب ترينيداد وتوباغو لكرة القدم",
    "tunisia men's a' international footballers": "لاعبو منتخب تونس لكرة القدم للرجال للمحليين",
    "tunisia national team": "منتخبات تونس الوطنية",
    "tunisia national teams": "منتخبات تونس الوطنية",
    "tunisia rally championship": "بطولة تونس للراليات",
    "tunisia sports templates": "قوالب تونس الرياضية",
    "ukraine women's international footballers": "لاعبات منتخب أوكرانيا لكرة القدم للسيدات",
    "venezuela international footballers": "لاعبو منتخب فنزويلا لكرة القدم",
    "venezuela rally championship": "بطولة فنزويلا للراليات",
    "yemen international footballers": "لاعبو منتخب اليمن لكرة القدم",
    "yemen international soccer players": "لاعبو منتخب اليمن لكرة القدم",
    "yemen rally championship": "بطولة اليمن للراليات",
    "yemen sports templates": "قوالب اليمن الرياضية",
    "zambia international footballers": "لاعبو منتخب زامبيا لكرة القدم",
    "zambia men's youth international footballers": "لاعبو منتخب زامبيا لكرة القدم للشباب",
    "zambia rally championship": "بطولة زامبيا للراليات",
    "zambia women's international footballers": "لاعبات منتخب زامبيا لكرة القدم للسيدات",
    "zimbabwe international footballers": "لاعبو منتخب زيمبابوي لكرة القدم",
    "zimbabwe rally championship": "بطولة زيمبابوي للراليات",
}


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_resolve_by_countries_names_1(category: str, expected: str) -> None:
    label1 = resolve_by_countries_names(category)
    assert label1 == expected


# =========================================================
#           DUMP
# =========================================================


TEMPORAL_CASES = [
    ("test_resolve_by_countries_names_1", data_1, resolve_by_countries_names),
]


@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback, do_strip=False)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
# TODO: ADD SOME DATA FROM D:/categories_bot/langlinks/z2_data/COUNTRY_YEAR.json
yemen at 2020 fifa women's world cup
# """

COUNTRY_YEAR_PARAMS = [
    "{year1}",
    "{country1}",
]

COUNTRY_YEAR_DATA_TO_CHECK = {
    "{year1} establishments in new {country1}": "تأسيسات سنة {year1} في {country1} الجديدة",  # 154
    "{year1} in ottoman {country1}": "{country1} العثمانية في {year1}",  # 65
}

# NOTE: patterns with only en-ar should be in formatted_data_en_ar_only countries_names.py to handle countries without gender details
# NOTE: patterns with only en-ar-time should be in COUNTRY_YEAR_DATA to handle countries-time without gender details

# 18th-century people of Dutch Empire
COUNTRY_YEAR_DATA = {
    "{year1} disestablishments in {country1}": "انحلالات سنة {year1} في {country1}",  # 4600
    "{year1} disestablishments in {country1} (state)": "انحلالات سنة {year1} في ولاية {country1}",  # 71
    "{year1} establishments in {country1}": "تأسيسات سنة {year1} في {country1}",  # 19853
    "{year1} establishments in {country1} territory": "تأسيسات سنة {year1} في إقليم {country1}",  # 231
    "{year1} establishments in {country1} (state)": "تأسيسات سنة {year1} في ولاية {country1}",  # 262
    "{year1} establishments in {country1} (u.s. state)": "تأسيسات سنة {year1} في ولاية {country1}",  # 138
    "{year1} establishments in {country1} city": "تأسيسات سنة {year1} في مدينة {country1}",  # 124
    "{year1} establishments in {country1}, d.c.": "تأسيسات سنة {year1} في {country1} العاصمة",  # 112
    "{year1} establishments in {country1} by state or union territory": "تأسيسات سنة {year1} في {country1} حسب الولاية أو الإقليم الاتحادي",  # 72
    # "20th-century executions by Gambia": "إعدامات في غامبيا في القرن 20",
    # "14th-century lords of Monaco": "لوردات موناكو في القرن 14",
    "{year1} lords of {country1}": "لوردات {country1} في {year1}",
    "{year1} kings of {country1}": "ملوك {country1} في {year1}",
    "{year1} {country1}": "{year1} في {country1}",  # 34632
    "{year1} in {country1}": "{year1} في {country1}",  # 34632
    "{year1} synagogues in {country1}": "كنس في {country1} في {year1}",
    "{year1} prime ministers of {country1}": "رؤساء وزراء {country1} في {year1}",
    "{year1} heads of state of {country1}": "قادة {country1} في {year1}",
    "{year1} elections in {country1}": "انتخابات {year1} في {country1}",  # 1550
    "{year1} people of {country1}": "أشخاص من {country1} {year1}",  # 34632
    "{year1} events in {country1}": "أحداث {year1} في {country1}",  # 7413
    "{year1} sports events in {country1}": "أحداث {year1} الرياضية في {country1}",  # 6108
    "{year1} crimes in {country1}": "جرائم {year1} في {country1}",  # 3966
    "{year1} murders in {country1}": "جرائم قتل في {country1} في {year1}",
    "{year1} disasters in {country1}": "كوارث في {country1} في {year1}",  # 2140
    "{year1} in {country1} by month": "{year1} في {country1} حسب الشهر",  # 1808
    "{year1} events in {country1} by month": "أحداث {year1} في {country1} حسب الشهر",  # 1382
    "years of {year1} in {country1}": "سنوات {year1} في {country1}",  # 922
    "{year1} in sports in {country1}": "الرياضة في {country1} في {year1}",  # 630
    "{year1} in {country1} by city": "{country1} في {year1} حسب المدينة",  # 486
    "{country1} at {year1} fifa world cup": "{country1} في كأس العالم {year1}",  # 466
    "{year1} in {country1} (state)": "ولاية {country1} في {year1}",  # 353
    "terrorist incidents in {country1} in {year1}": "حوادث إرهابية في {country1} في {year1}",  # 333
    "railway stations in {country1} opened in {year1}": "محطات السكك الحديدية في {country1} افتتحت في {year1}",  # 345
    "{year1} in {country1} territory": "إقليم {country1} في {year1}",  # 289
    "{year1} architecture in {country1}": "عمارة {year1} في {country1}",  # 317
    "{year1} in {country1} by state": "{year1} في {country1} حسب الولاية",  # 280
    "{year1} in {country1} by state or territory": "{country1} في {year1} حسب الولاية",  # 243
    "{year1} mass shootings in {country1}": "إطلاق نار عشوائي في {country1} في {year1}",  # 215
    "attacks in {country1} in {year1}": "هجمات في {country1} في {year1}",  # 247
    "{year1} roman catholic bishops in {country1}": "أساقفة كاثوليك رومان في {country1} في {year1}",  # 233
    "{year1} in {country1} city": "مدينة {country1} في {year1}",  # 150
    "{year1} religious buildings and structures in {country1}": "مبان ومنشآت دينية في {country1} في {year1}",  # 165
    "{year1} churches in {country1}": "كنائس في {country1} في {year1}",  # 172
    "{year1} in {country1} (u.s. state)": "ولاية {country1} في {year1}",  # 155
    "{country1} at uefa euro {year1}": "{country1} في بطولة أمم أوروبا {year1}",  # 183
    "{year1} mosques in {country1}": "مساجد في {country1} في {year1}",  # 175
    "{year1} in sport in {country1}": "أحداث {year1} الرياضية في {country1}",  # 143
    "{year1} crimes in {country1} by month": "جرائم {year1} في {country1} حسب الشهر",  # 167
    "{year1} mayors of places in {country1}": "رؤساء بلديات في {country1} في {year1}",  # 153
    "{year1} in {country1}, d.c.": "{country1} العاصمة في {year1}",  # 145
    "{year1} executions by {country1}": "إعدامات في {country1} في {year1}",  # 96
    "{year1} people from {country1}": "أشخاص من {country1} في {year1}",  # 115
    "{year1} fires in {country1}": "حرائق في {country1} في {year1}",  # 120
    "{year1} {country1} politicians": "سياسيو {country1} في {year1}",  # 88
    "{year1} in {country1} by province or territory": "{country1} في {year1} حسب المقاطعة أو الإقليم",  # 137
    "{year1} mass murder in {country1}": "قتل جماعي في {country1} في {year1}",  # 84
    "{year1} roman catholic archbishops in {country1}": "رؤساء أساقفة رومان كاثوليك في {country1} في {year1}",  # 129
    "{year1} in sports in {country1} (state)": "الرياضة في ولاية {country1} في {year1}",  # 131
    "{year1} in sports in {country1} city": "الرياضة في مدينة {country1} في {year1}",  # 126
    "{year1} tour de {country1}": "سباق طواف {country1} في {year1}",  # 110
    "{year1} monarchs in {country1}": "ملكيون في {country1} في {year1}",  # 82
    "{year1} in {country1} (country)": "{country1} في {year1}",  # 99
    "{country1} at {year1} fifa women's world cup": "{country1} في كأس العالم لكرة القدم للسيدات {year1}",  # 97
    "{year1} roman catholic church buildings in {country1}": "مبان كنائس رومانية كاثوليكية في {country1} في {year1}",  # 92
    "{year1} natural disasters in {country1}": "كوارث طبيعية في {country1} في {year1}",  # 84
    "{year1} floods in {country1}": "فيضانات في {country1} في {year1}",  # 62
    "{year1} awards in {country1}": "جوائز {year1} في {country1}",  # 78
    "aviation accidents and incidents in {country1} in {year1}": "حوادث طيران في {country1} في {year1}",  # 83
    "{year1} {country1} elections": "انتخابات {country1} في {year1}",  # 79
    "candidates in {year1} {country1} elections": "مرشحون في انتخابات {country1} في {year1}",  # 73
    "{year1} military history of {country1}": "تاريخ {country1} العسكري في {year1}",  # 57
    "{year1} controversies in {country1}": "خلافات في {country1} في {year1}",  # 53
    "{year1} members of {country1} general assembly": "أعضاء جمعية {country1} العامة في {year1}",  # 57
    "{country1} at {year1} copa américa": "{country1} في كوبا أمريكا {year1}",  # 57
    "{year1} in colony of {country1}": "{country1} في {year1}",  # 54
    "{year1} festivals in {country1}": "مهرجانات {year1} في {country1}",  # 55
    "{year1} members of {country1} legislature": "أعضاء هيئة {country1} التشريعية في {year1}",  # 54
    "{year1} {country1} state court judges": "قضاة محكمة ولاية {country1} في {year1}",  # 54
}



#
import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

fast_data_1 = {
    "April 2020 sports events in Africa": "أحداث أبريل 2020 الرياضية في إفريقيا",
    "April 2020 sports events in Argentina": "أحداث أبريل 2020 الرياضية في الأرجنتين",
    "April 2020 sports events in Asia": "أحداث أبريل 2020 الرياضية في آسيا",
    "April 2020 sports events in Australia": "أحداث أبريل 2020 الرياضية في أستراليا",
    "April 2020 sports events in Austria": "أحداث أبريل 2020 الرياضية في النمسا",
    "April 2020 sports events in Azerbaijan": "أحداث أبريل 2020 الرياضية في أذربيجان",
    "April 2020 sports events in Bahrain": "أحداث أبريل 2020 الرياضية في البحرين",
    "April 2020 sports events in Belgium": "أحداث أبريل 2020 الرياضية في بلجيكا",
    "April 2020 sports events in Brazil": "أحداث أبريل 2020 الرياضية في البرازيل",
    "April 2020 sports events in Bulgaria": "أحداث أبريل 2020 الرياضية في بلغاريا",
    "April 2020 sports events in Canada": "أحداث أبريل 2020 الرياضية في كندا",
    "April 2020 sports events in China": "أحداث أبريل 2020 الرياضية في الصين",
    "April 2020 sports events in Croatia": "أحداث أبريل 2020 الرياضية في كرواتيا",
    "April 2020 sports events in Egypt": "أحداث أبريل 2020 الرياضية في مصر",
    "April 2020 sports events in Europe": "أحداث أبريل 2020 الرياضية في أوروبا",
    "April 2020 sports events in France": "أحداث أبريل 2020 الرياضية في فرنسا",
    "April 2020 sports events in Germany": "أحداث أبريل 2020 الرياضية في ألمانيا",
    "April 2020 sports events in Greece": "أحداث أبريل 2020 الرياضية في اليونان",
    "April 2020 sports events in Hungary": "أحداث أبريل 2020 الرياضية في المجر",
    "April 2020 sports events in India": "أحداث أبريل 2020 الرياضية في الهند",
    "April 2020 sports events in Indonesia": "أحداث أبريل 2020 الرياضية في إندونيسيا",
    "April 2020 sports events in Italy": "أحداث أبريل 2020 الرياضية في إيطاليا",
    "April 2020 sports events in Japan": "أحداث أبريل 2020 الرياضية في اليابان",
    "April 2020 sports events in Malaysia": "أحداث أبريل 2020 الرياضية في ماليزيا",
    "April 2020 sports events in Mexico": "أحداث أبريل 2020 الرياضية في المكسيك",
    "April 2020 sports events in Monaco": "أحداث أبريل 2020 الرياضية في موناكو",
    "April 2020 sports events in Morocco": "أحداث أبريل 2020 الرياضية في المغرب",
    "April 2020 sports events in New Zealand": "أحداث أبريل 2020 الرياضية في نيوزيلندا",
    "April 2020 sports events in Nigeria": "أحداث أبريل 2020 الرياضية في نيجيريا",
    "April 2020 sports events in North America": "أحداث أبريل 2020 الرياضية في أمريكا الشمالية",
    "April 2020 sports events in Oceania": "أحداث أبريل 2020 الرياضية في أوقيانوسيا",
    "April 2020 sports events in Pakistan": "أحداث أبريل 2020 الرياضية في باكستان",
    "April 2020 sports events in Poland": "أحداث أبريل 2020 الرياضية في بولندا",
    "April 2020 sports events in Portugal": "أحداث أبريل 2020 الرياضية في البرتغال",
    "April 2020 sports events in Qatar": "أحداث أبريل 2020 الرياضية في قطر",
    "April 2020 sports events in Romania": "أحداث أبريل 2020 الرياضية في رومانيا",
    "April 2020 sports events in Russia": "أحداث أبريل 2020 الرياضية في روسيا",
    "April 2020 sports events in Saudi Arabia": "أحداث أبريل 2020 الرياضية في السعودية",
    "April 2020 sports events in Serbia": "أحداث أبريل 2020 الرياضية في صربيا",
    "April 2020 sports events in Singapore": "أحداث أبريل 2020 الرياضية في سنغافورة",
    "April 2020 sports events in South Africa": "أحداث أبريل 2020 الرياضية في جنوب إفريقيا",
    "April 2020 sports events in South America": "أحداث أبريل 2020 الرياضية في أمريكا الجنوبية",
    "April 2020 sports events in South Korea": "أحداث أبريل 2020 الرياضية في كوريا الجنوبية",
    "April 2020 sports events in Spain": "أحداث أبريل 2020 الرياضية في إسبانيا",
    "April 2020 sports events in Switzerland": "أحداث أبريل 2020 الرياضية في سويسرا",
    "April 2020 sports events in Taiwan": "أحداث أبريل 2020 الرياضية في تايوان",
    "April 2020 sports events in Thailand": "أحداث أبريل 2020 الرياضية في تايلاند",
    "April 2020 sports events in the Czech Republic": "أحداث أبريل 2020 الرياضية في التشيك",
    "April 2020 sports events in the Netherlands": "أحداث أبريل 2020 الرياضية في هولندا",
    "April 2020 sports events in the Philippines": "أحداث أبريل 2020 الرياضية في الفلبين",
    "April 2020 sports events in the United Arab Emirates": "أحداث أبريل 2020 الرياضية في الإمارات العربية المتحدة",
    "April 2020 sports events in the United Kingdom": "أحداث أبريل 2020 الرياضية في المملكة المتحدة",
    "April 2020 sports events in the United States": "أحداث أبريل 2020 الرياضية في الولايات المتحدة",
    "April 2020 sports events in Tunisia": "أحداث أبريل 2020 الرياضية في تونس",
    "April 2020 sports events in Turkey": "أحداث أبريل 2020 الرياضية في تركيا",
    "April 2020 sports events in Ukraine": "أحداث أبريل 2020 الرياضية في أوكرانيا",
    "april 2020 sports-events in europe": "أحداث أبريل 2020 الرياضية في أوروبا",
    "april 2020 sports-events in france": "أحداث أبريل 2020 الرياضية في فرنسا",
    "april 2020 sports-events in malaysia": "أحداث أبريل 2020 الرياضية في ماليزيا",
    "april 2020 sports-events in north america": "أحداث أبريل 2020 الرياضية في أمريكا الشمالية",
    "april 2020 sports-events in oceania": "أحداث أبريل 2020 الرياضية في أوقيانوسيا",
    "april 2020 sports-events in south america": "أحداث أبريل 2020 الرياضية في أمريكا الجنوبية",
    "april 2020 sports-events in the united kingdom": "أحداث أبريل 2020 الرياضية في المملكة المتحدة",
    "april 2020 sports-events in the united states": "أحداث أبريل 2020 الرياضية في الولايات المتحدة",
    "april 2020 sports-events in united kingdom": "أحداث أبريل 2020 الرياضية في المملكة المتحدة",
    "August 2020 sports events in Africa": "أحداث أغسطس 2020 الرياضية في إفريقيا",
    "August 2020 sports events in Argentina": "أحداث أغسطس 2020 الرياضية في الأرجنتين",
    "August 2020 sports events in Asia": "أحداث أغسطس 2020 الرياضية في آسيا",
    "August 2020 sports events in Australia": "أحداث أغسطس 2020 الرياضية في أستراليا",
    "August 2020 sports events in Austria": "أحداث أغسطس 2020 الرياضية في النمسا",
    "August 2020 sports events in Azerbaijan": "أحداث أغسطس 2020 الرياضية في أذربيجان",
    "August 2020 sports events in Bahrain": "أحداث أغسطس 2020 الرياضية في البحرين",
    "August 2020 sports events in Belgium": "أحداث أغسطس 2020 الرياضية في بلجيكا",
    "August 2020 sports events in Brazil": "أحداث أغسطس 2020 الرياضية في البرازيل",
    "August 2020 sports events in Bulgaria": "أحداث أغسطس 2020 الرياضية في بلغاريا",
    "August 2020 sports events in Canada": "أحداث أغسطس 2020 الرياضية في كندا",
    "August 2020 sports events in China": "أحداث أغسطس 2020 الرياضية في الصين",
    "August 2020 sports events in Croatia": "أحداث أغسطس 2020 الرياضية في كرواتيا",
    "August 2020 sports events in Ecuador": "أحداث أغسطس 2020 الرياضية في الإكوادور",
    "August 2020 sports events in Egypt": "أحداث أغسطس 2020 الرياضية في مصر",
    "August 2020 sports events in Europe": "أحداث أغسطس 2020 الرياضية في أوروبا",
    "August 2020 sports events in France": "أحداث أغسطس 2020 الرياضية في فرنسا",
    "August 2020 sports events in Germany": "أحداث أغسطس 2020 الرياضية في ألمانيا",
    "August 2020 sports events in Greece": "أحداث أغسطس 2020 الرياضية في اليونان",
    "August 2020 sports events in Hungary": "أحداث أغسطس 2020 الرياضية في المجر",
    "August 2020 sports events in India": "أحداث أغسطس 2020 الرياضية في الهند",
    "August 2020 sports events in Indonesia": "أحداث أغسطس 2020 الرياضية في إندونيسيا",
    "August 2020 sports events in Iraq": "أحداث أغسطس 2020 الرياضية في العراق",
    "August 2020 sports events in Ireland": "أحداث أغسطس 2020 الرياضية في أيرلندا",
    "August 2020 sports events in Italy": "أحداث أغسطس 2020 الرياضية في إيطاليا",
    "August 2020 sports events in Japan": "أحداث أغسطس 2020 الرياضية في اليابان",
    "August 2020 sports events in Malaysia": "أحداث أغسطس 2020 الرياضية في ماليزيا",
    "August 2020 sports events in Mexico": "أحداث أغسطس 2020 الرياضية في المكسيك",
    "August 2020 sports events in New Zealand": "أحداث أغسطس 2020 الرياضية في نيوزيلندا",
    "August 2020 sports events in Nigeria": "أحداث أغسطس 2020 الرياضية في نيجيريا",
    "August 2020 sports events in North America": "أحداث أغسطس 2020 الرياضية في أمريكا الشمالية",
    "August 2020 sports events in Oceania": "أحداث أغسطس 2020 الرياضية في أوقيانوسيا",
    "August 2020 sports events in Pakistan": "أحداث أغسطس 2020 الرياضية في باكستان",
    "August 2020 sports events in Poland": "أحداث أغسطس 2020 الرياضية في بولندا",
    "August 2020 sports events in Portugal": "أحداث أغسطس 2020 الرياضية في البرتغال",
    "August 2020 sports events in Romania": "أحداث أغسطس 2020 الرياضية في رومانيا",
    "August 2020 sports events in Russia": "أحداث أغسطس 2020 الرياضية في روسيا",
    "August 2020 sports events in Saudi Arabia": "أحداث أغسطس 2020 الرياضية في السعودية",
    "August 2020 sports events in Serbia": "أحداث أغسطس 2020 الرياضية في صربيا",
    "August 2020 sports events in Singapore": "أحداث أغسطس 2020 الرياضية في سنغافورة",
    "August 2020 sports events in Slovakia": "أحداث أغسطس 2020 الرياضية في سلوفاكيا",
    "August 2020 sports events in South Africa": "أحداث أغسطس 2020 الرياضية في جنوب إفريقيا",
    "August 2020 sports events in South America": "أحداث أغسطس 2020 الرياضية في أمريكا الجنوبية",
    "August 2020 sports events in South Korea": "أحداث أغسطس 2020 الرياضية في كوريا الجنوبية",
    "August 2020 sports events in Spain": "أحداث أغسطس 2020 الرياضية في إسبانيا",
    "August 2020 sports events in Switzerland": "أحداث أغسطس 2020 الرياضية في سويسرا",
    "August 2020 sports events in Taiwan": "أحداث أغسطس 2020 الرياضية في تايوان",
    "August 2020 sports events in Thailand": "أحداث أغسطس 2020 الرياضية في تايلاند",
    "August 2020 sports events in the Czech Republic": "أحداث أغسطس 2020 الرياضية في التشيك",
    "August 2020 sports events in the Netherlands": "أحداث أغسطس 2020 الرياضية في هولندا",
    "August 2020 sports events in the Philippines": "أحداث أغسطس 2020 الرياضية في الفلبين",
    "August 2020 sports events in the United Arab Emirates": "أحداث أغسطس 2020 الرياضية في الإمارات العربية المتحدة",
    "August 2020 sports events in the United Kingdom": "أحداث أغسطس 2020 الرياضية في المملكة المتحدة",
    "August 2020 sports events in the United States": "أحداث أغسطس 2020 الرياضية في الولايات المتحدة",
    "August 2020 sports events in Tunisia": "أحداث أغسطس 2020 الرياضية في تونس",
    "August 2020 sports events in Turkey": "أحداث أغسطس 2020 الرياضية في تركيا",
    "August 2020 sports events in Ukraine": "أحداث أغسطس 2020 الرياضية في أوكرانيا",
    "August 2020 sports events in Vanuatu": "أحداث أغسطس 2020 الرياضية في فانواتو",
    "August 2020 sports events in Vietnam": "أحداث أغسطس 2020 الرياضية في فيتنام",
    "august 2020 sports-events in australia": "أحداث أغسطس 2020 الرياضية في أستراليا",
    "august 2020 sports-events in france": "أحداث أغسطس 2020 الرياضية في فرنسا",
    "august 2020 sports-events in north america": "أحداث أغسطس 2020 الرياضية في أمريكا الشمالية",
    "august 2020 sports-events in oceania": "أحداث أغسطس 2020 الرياضية في أوقيانوسيا",
    "august 2020 sports-events in south korea": "أحداث أغسطس 2020 الرياضية في كوريا الجنوبية",
    "august 2020 sports-events in spain": "أحداث أغسطس 2020 الرياضية في إسبانيا",
    "august 2020 sports-events in the united kingdom": "أحداث أغسطس 2020 الرياضية في المملكة المتحدة",
    "august 2020 sports-events in the united states": "أحداث أغسطس 2020 الرياضية في الولايات المتحدة",
    "December 2020 sports events in Africa": "أحداث ديسمبر 2020 الرياضية في إفريقيا",
    "December 2020 sports events in Argentina": "أحداث ديسمبر 2020 الرياضية في الأرجنتين",
    "December 2020 sports events in Asia": "أحداث ديسمبر 2020 الرياضية في آسيا",
    "December 2020 sports events in Australia": "أحداث ديسمبر 2020 الرياضية في أستراليا",
    "December 2020 sports events in Austria": "أحداث ديسمبر 2020 الرياضية في النمسا",
    "December 2020 sports events in Bangladesh": "أحداث ديسمبر 2020 الرياضية في بنغلاديش",
    "December 2020 sports events in Brazil": "أحداث ديسمبر 2020 الرياضية في البرازيل",
    "December 2020 sports events in Canada": "أحداث ديسمبر 2020 الرياضية في كندا",
    "December 2020 sports events in China": "أحداث ديسمبر 2020 الرياضية في الصين",
    "December 2020 sports events in Egypt": "أحداث ديسمبر 2020 الرياضية في مصر",
    "December 2020 sports events in El Salvador": "أحداث ديسمبر 2020 الرياضية في السلفادور",
    "December 2020 sports events in Europe": "أحداث ديسمبر 2020 الرياضية في أوروبا",
    "December 2020 sports events in France": "أحداث ديسمبر 2020 الرياضية في فرنسا",
    "December 2020 sports events in Germany": "أحداث ديسمبر 2020 الرياضية في ألمانيا",
    "December 2020 sports events in Greece": "أحداث ديسمبر 2020 الرياضية في اليونان",
    "December 2020 sports events in India": "أحداث ديسمبر 2020 الرياضية في الهند",
    "December 2020 sports events in Indonesia": "أحداث ديسمبر 2020 الرياضية في إندونيسيا",
    "December 2020 sports events in Iran": "أحداث ديسمبر 2020 الرياضية في إيران",
    "December 2020 sports events in Ireland": "أحداث ديسمبر 2020 الرياضية في أيرلندا",
    "December 2020 sports events in Italy": "أحداث ديسمبر 2020 الرياضية في إيطاليا",
    "December 2020 sports events in Japan": "أحداث ديسمبر 2020 الرياضية في اليابان",
    "December 2020 sports events in Malaysia": "أحداث ديسمبر 2020 الرياضية في ماليزيا",
    "December 2020 sports events in Mexico": "أحداث ديسمبر 2020 الرياضية في المكسيك",
    "December 2020 sports events in Morocco": "أحداث ديسمبر 2020 الرياضية في المغرب",
    "December 2020 sports events in New Zealand": "أحداث ديسمبر 2020 الرياضية في نيوزيلندا",
    "December 2020 sports events in North America": "أحداث ديسمبر 2020 الرياضية في أمريكا الشمالية",
    "December 2020 sports events in Oceania": "أحداث ديسمبر 2020 الرياضية في أوقيانوسيا",
    "December 2020 sports events in Pakistan": "أحداث ديسمبر 2020 الرياضية في باكستان",
    "December 2020 sports events in Poland": "أحداث ديسمبر 2020 الرياضية في بولندا",
    "December 2020 sports events in Portugal": "أحداث ديسمبر 2020 الرياضية في البرتغال",
    "December 2020 sports events in Qatar": "أحداث ديسمبر 2020 الرياضية في قطر",
    "December 2020 sports events in Russia": "أحداث ديسمبر 2020 الرياضية في روسيا",
    "December 2020 sports events in Saudi Arabia": "أحداث ديسمبر 2020 الرياضية في السعودية",
    "December 2020 sports events in Singapore": "أحداث ديسمبر 2020 الرياضية في سنغافورة",
    "December 2020 sports events in South Africa": "أحداث ديسمبر 2020 الرياضية في جنوب إفريقيا",
    "December 2020 sports events in South America": "أحداث ديسمبر 2020 الرياضية في أمريكا الجنوبية",
    "December 2020 sports events in South Korea": "أحداث ديسمبر 2020 الرياضية في كوريا الجنوبية",
    "December 2020 sports events in Spain": "أحداث ديسمبر 2020 الرياضية في إسبانيا",
    "December 2020 sports events in Switzerland": "أحداث ديسمبر 2020 الرياضية في سويسرا",
    "December 2020 sports events in Taiwan": "أحداث ديسمبر 2020 الرياضية في تايوان",
    "December 2020 sports events in Thailand": "أحداث ديسمبر 2020 الرياضية في تايلاند",
    "December 2020 sports events in the Czech Republic": "أحداث ديسمبر 2020 الرياضية في التشيك",
    "December 2020 sports events in the Netherlands": "أحداث ديسمبر 2020 الرياضية في هولندا",
    "December 2020 sports events in the Philippines": "أحداث ديسمبر 2020 الرياضية في الفلبين",
    "December 2020 sports events in the United Arab Emirates": "أحداث ديسمبر 2020 الرياضية في الإمارات العربية المتحدة",
    "December 2020 sports events in the United Kingdom": "أحداث ديسمبر 2020 الرياضية في المملكة المتحدة",
    "December 2020 sports events in the United States": "أحداث ديسمبر 2020 الرياضية في الولايات المتحدة",
    "December 2020 sports events in Tunisia": "أحداث ديسمبر 2020 الرياضية في تونس",
    "December 2020 sports events in Turkey": "أحداث ديسمبر 2020 الرياضية في تركيا",
    "December 2020 sports events in Ukraine": "أحداث ديسمبر 2020 الرياضية في أوكرانيا",
    "december 2020 sports-events in the philippines": "أحداث ديسمبر 2020 الرياضية في الفلبين",
    "december 2020 sports-events in the united states": "أحداث ديسمبر 2020 الرياضية في الولايات المتحدة",
    "december 2020 sports-events in united kingdom": "أحداث ديسمبر 2020 الرياضية في المملكة المتحدة",
    "december 2020 sports-events in united states": "أحداث ديسمبر 2020 الرياضية في الولايات المتحدة",
    "February 2020 sports events in Africa": "أحداث فبراير 2020 الرياضية في إفريقيا",
    "February 2020 sports events in Argentina": "أحداث فبراير 2020 الرياضية في الأرجنتين",
    "February 2020 sports events in Asia": "أحداث فبراير 2020 الرياضية في آسيا",
    "February 2020 sports events in Australia": "أحداث فبراير 2020 الرياضية في أستراليا",
    "February 2020 sports events in Austria": "أحداث فبراير 2020 الرياضية في النمسا",
    "February 2020 sports events in Azerbaijan": "أحداث فبراير 2020 الرياضية في أذربيجان",
    "February 2020 sports events in Bahrain": "أحداث فبراير 2020 الرياضية في البحرين",
    "February 2020 sports events in Bangladesh": "أحداث فبراير 2020 الرياضية في بنغلاديش",
    "February 2020 sports events in Belgium": "أحداث فبراير 2020 الرياضية في بلجيكا",
    "February 2020 sports events in Brazil": "أحداث فبراير 2020 الرياضية في البرازيل",
    "February 2020 sports events in Bulgaria": "أحداث فبراير 2020 الرياضية في بلغاريا",
    "February 2020 sports events in Canada": "أحداث فبراير 2020 الرياضية في كندا",
    "February 2020 sports events in China": "أحداث فبراير 2020 الرياضية في الصين",
    "February 2020 sports events in Costa Rica": "أحداث فبراير 2020 الرياضية في كوستاريكا",
    "February 2020 sports events in Croatia": "أحداث فبراير 2020 الرياضية في كرواتيا",
    "February 2020 sports events in Egypt": "أحداث فبراير 2020 الرياضية في مصر",
    "February 2020 sports events in Europe": "أحداث فبراير 2020 الرياضية في أوروبا",
    "February 2020 sports events in Fiji": "أحداث فبراير 2020 الرياضية في فيجي",
    "February 2020 sports events in France": "أحداث فبراير 2020 الرياضية في فرنسا",
    "February 2020 sports events in Germany": "أحداث فبراير 2020 الرياضية في ألمانيا",
    "February 2020 sports events in Hungary": "أحداث فبراير 2020 الرياضية في المجر",
    "February 2020 sports events in India": "أحداث فبراير 2020 الرياضية في الهند",
    "February 2020 sports events in Iran": "أحداث فبراير 2020 الرياضية في إيران",
    "February 2020 sports events in Ireland": "أحداث فبراير 2020 الرياضية في أيرلندا",
    "February 2020 sports events in Italy": "أحداث فبراير 2020 الرياضية في إيطاليا",
    "February 2020 sports events in Japan": "أحداث فبراير 2020 الرياضية في اليابان",
    "February 2020 sports events in Malaysia": "أحداث فبراير 2020 الرياضية في ماليزيا",
    "February 2020 sports events in Mexico": "أحداث فبراير 2020 الرياضية في المكسيك",
    "February 2020 sports events in New Zealand": "أحداث فبراير 2020 الرياضية في نيوزيلندا",
    "February 2020 sports events in Nigeria": "أحداث فبراير 2020 الرياضية في نيجيريا",
    "February 2020 sports events in North America": "أحداث فبراير 2020 الرياضية في أمريكا الشمالية",
    "February 2020 sports events in Oceania": "أحداث فبراير 2020 الرياضية في أوقيانوسيا",
    "February 2020 sports events in Pakistan": "أحداث فبراير 2020 الرياضية في باكستان",
    "February 2020 sports events in Poland": "أحداث فبراير 2020 الرياضية في بولندا",
    "February 2020 sports events in Portugal": "أحداث فبراير 2020 الرياضية في البرتغال",
    "February 2020 sports events in Qatar": "أحداث فبراير 2020 الرياضية في قطر",
    "February 2020 sports events in Romania": "أحداث فبراير 2020 الرياضية في رومانيا",
    "February 2020 sports events in Russia": "أحداث فبراير 2020 الرياضية في روسيا",
    "February 2020 sports events in Saudi Arabia": "أحداث فبراير 2020 الرياضية في السعودية",
    "February 2020 sports events in Serbia": "أحداث فبراير 2020 الرياضية في صربيا",
    "February 2020 sports events in Singapore": "أحداث فبراير 2020 الرياضية في سنغافورة",
    "February 2020 sports events in South Africa": "أحداث فبراير 2020 الرياضية في جنوب إفريقيا",
    "February 2020 sports events in South America": "أحداث فبراير 2020 الرياضية في أمريكا الجنوبية",
    "February 2020 sports events in South Korea": "أحداث فبراير 2020 الرياضية في كوريا الجنوبية",
    "February 2020 sports events in Spain": "أحداث فبراير 2020 الرياضية في إسبانيا",
    "February 2020 sports events in Switzerland": "أحداث فبراير 2020 الرياضية في سويسرا",
    "February 2020 sports events in Taiwan": "أحداث فبراير 2020 الرياضية في تايوان",
    "February 2020 sports events in Thailand": "أحداث فبراير 2020 الرياضية في تايلاند",
    "February 2020 sports events in the Czech Republic": "أحداث فبراير 2020 الرياضية في التشيك",
    "February 2020 sports events in the Netherlands": "أحداث فبراير 2020 الرياضية في هولندا",
    "February 2020 sports events in the Philippines": "أحداث فبراير 2020 الرياضية في الفلبين",
    "February 2020 sports events in the United Arab Emirates": "أحداث فبراير 2020 الرياضية في الإمارات العربية المتحدة",
    "February 2020 sports events in the United Kingdom": "أحداث فبراير 2020 الرياضية في المملكة المتحدة",
    "February 2020 sports events in the United States": "أحداث فبراير 2020 الرياضية في الولايات المتحدة",
    "February 2020 sports events in Tunisia": "أحداث فبراير 2020 الرياضية في تونس",
    "February 2020 sports events in Turkey": "أحداث فبراير 2020 الرياضية في تركيا",
    "February 2020 sports events in Ukraine": "أحداث فبراير 2020 الرياضية في أوكرانيا",
    "february 2020 sports-events in asia": "أحداث فبراير 2020 الرياضية في آسيا",
    "february 2020 sports-events in germany": "أحداث فبراير 2020 الرياضية في ألمانيا",
    "January 2020 sports events in Africa": "أحداث يناير 2020 الرياضية في إفريقيا",
    "January 2020 sports events in Algeria": "أحداث يناير 2020 الرياضية في الجزائر",
    "January 2020 sports events in Argentina": "أحداث يناير 2020 الرياضية في الأرجنتين",
    "January 2020 sports events in Asia": "أحداث يناير 2020 الرياضية في آسيا",
    "January 2020 sports events in Australia": "أحداث يناير 2020 الرياضية في أستراليا",
    "January 2020 sports events in Austria": "أحداث يناير 2020 الرياضية في النمسا",
    "January 2020 sports events in Bahrain": "أحداث يناير 2020 الرياضية في البحرين",
    "January 2020 sports events in Bangladesh": "أحداث يناير 2020 الرياضية في بنغلاديش",
    "January 2020 sports events in Belgium": "أحداث يناير 2020 الرياضية في بلجيكا",
    "January 2020 sports events in Brazil": "أحداث يناير 2020 الرياضية في البرازيل",
    "January 2020 sports events in Bulgaria": "أحداث يناير 2020 الرياضية في بلغاريا",
    "January 2020 sports events in Canada": "أحداث يناير 2020 الرياضية في كندا",
    "January 2020 sports events in China": "أحداث يناير 2020 الرياضية في الصين",
    "January 2020 sports events in Croatia": "أحداث يناير 2020 الرياضية في كرواتيا",
    "January 2020 sports events in Egypt": "أحداث يناير 2020 الرياضية في مصر",
    "January 2020 sports events in Europe": "أحداث يناير 2020 الرياضية في أوروبا",
    "January 2020 sports events in Fiji": "أحداث يناير 2020 الرياضية في فيجي",
    "January 2020 sports events in France": "أحداث يناير 2020 الرياضية في فرنسا",
    "January 2020 sports events in Germany": "أحداث يناير 2020 الرياضية في ألمانيا",
    "January 2020 sports events in Hungary": "أحداث يناير 2020 الرياضية في المجر",
    "January 2020 sports events in India": "أحداث يناير 2020 الرياضية في الهند",
    "January 2020 sports events in Indonesia": "أحداث يناير 2020 الرياضية في إندونيسيا",
    "January 2020 sports events in Ireland": "أحداث يناير 2020 الرياضية في أيرلندا",
    "January 2020 sports events in Italy": "أحداث يناير 2020 الرياضية في إيطاليا",
    "January 2020 sports events in Japan": "أحداث يناير 2020 الرياضية في اليابان",
    "January 2020 sports events in Malaysia": "أحداث يناير 2020 الرياضية في ماليزيا",
    "January 2020 sports events in Mexico": "أحداث يناير 2020 الرياضية في المكسيك",
    "January 2020 sports events in Morocco": "أحداث يناير 2020 الرياضية في المغرب",
    "January 2020 sports events in New Zealand": "أحداث يناير 2020 الرياضية في نيوزيلندا",
    "January 2020 sports events in North America": "أحداث يناير 2020 الرياضية في أمريكا الشمالية",
    "January 2020 sports events in Oceania": "أحداث يناير 2020 الرياضية في أوقيانوسيا",
    "January 2020 sports events in Oman": "أحداث يناير 2020 الرياضية في سلطنة عمان",
    "January 2020 sports events in Pakistan": "أحداث يناير 2020 الرياضية في باكستان",
    "January 2020 sports events in Poland": "أحداث يناير 2020 الرياضية في بولندا",
    "January 2020 sports events in Portugal": "أحداث يناير 2020 الرياضية في البرتغال",
    "January 2020 sports events in Qatar": "أحداث يناير 2020 الرياضية في قطر",
    "January 2020 sports events in Russia": "أحداث يناير 2020 الرياضية في روسيا",
    "January 2020 sports events in Saudi Arabia": "أحداث يناير 2020 الرياضية في السعودية",
    "January 2020 sports events in Serbia": "أحداث يناير 2020 الرياضية في صربيا",
    "January 2020 sports events in Singapore": "أحداث يناير 2020 الرياضية في سنغافورة",
    "January 2020 sports events in Slovakia": "أحداث يناير 2020 الرياضية في سلوفاكيا",
    "January 2020 sports events in South Africa": "أحداث يناير 2020 الرياضية في جنوب إفريقيا",
    "January 2020 sports events in South America": "أحداث يناير 2020 الرياضية في أمريكا الجنوبية",
    "January 2020 sports events in South Korea": "أحداث يناير 2020 الرياضية في كوريا الجنوبية",
    "January 2020 sports events in Spain": "أحداث يناير 2020 الرياضية في إسبانيا",
    "January 2020 sports events in Switzerland": "أحداث يناير 2020 الرياضية في سويسرا",
    "January 2020 sports events in Thailand": "أحداث يناير 2020 الرياضية في تايلاند",
    "January 2020 sports events in the Netherlands": "أحداث يناير 2020 الرياضية في هولندا",
    "January 2020 sports events in the Philippines": "أحداث يناير 2020 الرياضية في الفلبين",
    "January 2020 sports events in the United Arab Emirates": "أحداث يناير 2020 الرياضية في الإمارات العربية المتحدة",
    "January 2020 sports events in the United Kingdom": "أحداث يناير 2020 الرياضية في المملكة المتحدة",
    "January 2020 sports events in the United States": "أحداث يناير 2020 الرياضية في الولايات المتحدة",
    "January 2020 sports events in Tunisia": "أحداث يناير 2020 الرياضية في تونس",
    "January 2020 sports events in Turkey": "أحداث يناير 2020 الرياضية في تركيا",
    "January 2020 sports events in Vietnam": "أحداث يناير 2020 الرياضية في فيتنام",
    "january 2020 sports-events in austria": "أحداث يناير 2020 الرياضية في النمسا",
    "january 2020 sports-events in europe": "أحداث يناير 2020 الرياضية في أوروبا",
    "january 2020 sports-events in germany": "أحداث يناير 2020 الرياضية في ألمانيا",
    "january 2020 sports-events in north america": "أحداث يناير 2020 الرياضية في أمريكا الشمالية",
    "january 2020 sports-events in russia": "أحداث يناير 2020 الرياضية في روسيا",
    "July 2020 sports events in Africa": "أحداث يوليو 2020 الرياضية في إفريقيا",
    "July 2020 sports events in Algeria": "أحداث يوليو 2020 الرياضية في الجزائر",
    "July 2020 sports events in Argentina": "أحداث يوليو 2020 الرياضية في الأرجنتين",
    "July 2020 sports events in Asia": "أحداث يوليو 2020 الرياضية في آسيا",
    "July 2020 sports events in Australia": "أحداث يوليو 2020 الرياضية في أستراليا",
    "July 2020 sports events in Austria": "أحداث يوليو 2020 الرياضية في النمسا",
    "July 2020 sports events in Azerbaijan": "أحداث يوليو 2020 الرياضية في أذربيجان",
    "July 2020 sports events in Bahrain": "أحداث يوليو 2020 الرياضية في البحرين",
    "July 2020 sports events in Bangladesh": "أحداث يوليو 2020 الرياضية في بنغلاديش",
    "July 2020 sports events in Belgium": "أحداث يوليو 2020 الرياضية في بلجيكا",
    "July 2020 sports events in Brazil": "أحداث يوليو 2020 الرياضية في البرازيل",
    "July 2020 sports events in Bulgaria": "أحداث يوليو 2020 الرياضية في بلغاريا",
    "July 2020 sports events in Canada": "أحداث يوليو 2020 الرياضية في كندا",
    "July 2020 sports events in China": "أحداث يوليو 2020 الرياضية في الصين",
    "July 2020 sports events in Croatia": "أحداث يوليو 2020 الرياضية في كرواتيا",
    "July 2020 sports events in Egypt": "أحداث يوليو 2020 الرياضية في مصر",
    "July 2020 sports events in Europe": "أحداث يوليو 2020 الرياضية في أوروبا",
    "July 2020 sports events in Fiji": "أحداث يوليو 2020 الرياضية في فيجي",
    "July 2020 sports events in France": "أحداث يوليو 2020 الرياضية في فرنسا",
    "July 2020 sports events in Germany": "أحداث يوليو 2020 الرياضية في ألمانيا",
    "July 2020 sports events in Greece": "أحداث يوليو 2020 الرياضية في اليونان",
    "July 2020 sports events in Hungary": "أحداث يوليو 2020 الرياضية في المجر",
    "July 2020 sports events in India": "أحداث يوليو 2020 الرياضية في الهند",
    "July 2020 sports events in Indonesia": "أحداث يوليو 2020 الرياضية في إندونيسيا",
    "July 2020 sports events in Iran": "أحداث يوليو 2020 الرياضية في إيران",
    "July 2020 sports events in Iraq": "أحداث يوليو 2020 الرياضية في العراق",
    "July 2020 sports events in Ireland": "أحداث يوليو 2020 الرياضية في أيرلندا",
    "July 2020 sports events in Italy": "أحداث يوليو 2020 الرياضية في إيطاليا",
    "July 2020 sports events in Japan": "أحداث يوليو 2020 الرياضية في اليابان",
    "July 2020 sports events in Lebanon": "أحداث يوليو 2020 الرياضية في لبنان",
    "July 2020 sports events in Malaysia": "أحداث يوليو 2020 الرياضية في ماليزيا",
    "July 2020 sports events in Mexico": "أحداث يوليو 2020 الرياضية في المكسيك",
    "July 2020 sports events in Morocco": "أحداث يوليو 2020 الرياضية في المغرب",
    "July 2020 sports events in New Zealand": "أحداث يوليو 2020 الرياضية في نيوزيلندا",
    "July 2020 sports events in North America": "أحداث يوليو 2020 الرياضية في أمريكا الشمالية",
    "July 2020 sports events in Oceania": "أحداث يوليو 2020 الرياضية في أوقيانوسيا",
    "July 2020 sports events in Pakistan": "أحداث يوليو 2020 الرياضية في باكستان",
    "July 2020 sports events in Poland": "أحداث يوليو 2020 الرياضية في بولندا",
    "July 2020 sports events in Portugal": "أحداث يوليو 2020 الرياضية في البرتغال",
    "July 2020 sports events in Romania": "أحداث يوليو 2020 الرياضية في رومانيا",
    "July 2020 sports events in Russia": "أحداث يوليو 2020 الرياضية في روسيا",
    "July 2020 sports events in Saudi Arabia": "أحداث يوليو 2020 الرياضية في السعودية",
    "July 2020 sports events in Serbia": "أحداث يوليو 2020 الرياضية في صربيا",
    "July 2020 sports events in Singapore": "أحداث يوليو 2020 الرياضية في سنغافورة",
    "July 2020 sports events in Slovakia": "أحداث يوليو 2020 الرياضية في سلوفاكيا",
    "July 2020 sports events in South Africa": "أحداث يوليو 2020 الرياضية في جنوب إفريقيا",
    "July 2020 sports events in South America": "أحداث يوليو 2020 الرياضية في أمريكا الجنوبية",
    "July 2020 sports events in South Korea": "أحداث يوليو 2020 الرياضية في كوريا الجنوبية",
    "July 2020 sports events in Spain": "أحداث يوليو 2020 الرياضية في إسبانيا",
    "July 2020 sports events in Switzerland": "أحداث يوليو 2020 الرياضية في سويسرا",
    "July 2020 sports events in Taiwan": "أحداث يوليو 2020 الرياضية في تايوان",
    "July 2020 sports events in Thailand": "أحداث يوليو 2020 الرياضية في تايلاند",
    "July 2020 sports events in the Czech Republic": "أحداث يوليو 2020 الرياضية في التشيك",
    "July 2020 sports events in the Netherlands": "أحداث يوليو 2020 الرياضية في هولندا",
    "July 2020 sports events in the Philippines": "أحداث يوليو 2020 الرياضية في الفلبين",
    "July 2020 sports events in the United Arab Emirates": "أحداث يوليو 2020 الرياضية في الإمارات العربية المتحدة",
    "July 2020 sports events in the United Kingdom": "أحداث يوليو 2020 الرياضية في المملكة المتحدة",
    "July 2020 sports events in the United States": "أحداث يوليو 2020 الرياضية في الولايات المتحدة",
    "July 2020 sports events in Tunisia": "أحداث يوليو 2020 الرياضية في تونس",
    "July 2020 sports events in Turkey": "أحداث يوليو 2020 الرياضية في تركيا",
    "July 2020 sports events in Ukraine": "أحداث يوليو 2020 الرياضية في أوكرانيا",
    "july 2020 sports-events in africa": "أحداث يوليو 2020 الرياضية في إفريقيا",
    "july 2020 sports-events in asia": "أحداث يوليو 2020 الرياضية في آسيا",
    "july 2020 sports-events in australia": "أحداث يوليو 2020 الرياضية في أستراليا",
    "july 2020 sports-events in austria": "أحداث يوليو 2020 الرياضية في النمسا",
    "july 2020 sports-events in china": "أحداث يوليو 2020 الرياضية في الصين",
    "july 2020 sports-events in indonesia": "أحداث يوليو 2020 الرياضية في إندونيسيا",
    "july 2020 sports-events in north america": "أحداث يوليو 2020 الرياضية في أمريكا الشمالية",
    "June 2020 sports events in Africa": "أحداث يونيو 2020 الرياضية في إفريقيا",
    "June 2020 sports events in Algeria": "أحداث يونيو 2020 الرياضية في الجزائر",
    "June 2020 sports events in Argentina": "أحداث يونيو 2020 الرياضية في الأرجنتين",
    "June 2020 sports events in Asia": "أحداث يونيو 2020 الرياضية في آسيا",
    "June 2020 sports events in Australia": "أحداث يونيو 2020 الرياضية في أستراليا",
    "June 2020 sports events in Austria": "أحداث يونيو 2020 الرياضية في النمسا",
    "June 2020 sports events in Azerbaijan": "أحداث يونيو 2020 الرياضية في أذربيجان",
    "June 2020 sports events in Bahrain": "أحداث يونيو 2020 الرياضية في البحرين",
    "June 2020 sports events in Belgium": "أحداث يونيو 2020 الرياضية في بلجيكا",
    "June 2020 sports events in Brazil": "أحداث يونيو 2020 الرياضية في البرازيل",
    "June 2020 sports events in Bulgaria": "أحداث يونيو 2020 الرياضية في بلغاريا",
    "June 2020 sports events in Canada": "أحداث يونيو 2020 الرياضية في كندا",
    "June 2020 sports events in China": "أحداث يونيو 2020 الرياضية في الصين",
    "June 2020 sports events in Croatia": "أحداث يونيو 2020 الرياضية في كرواتيا",
    "June 2020 sports events in Egypt": "أحداث يونيو 2020 الرياضية في مصر",
    "June 2020 sports events in Europe": "أحداث يونيو 2020 الرياضية في أوروبا",
    "June 2020 sports events in Fiji": "أحداث يونيو 2020 الرياضية في فيجي",
    "June 2020 sports events in France": "أحداث يونيو 2020 الرياضية في فرنسا",
    "June 2020 sports events in Germany": "أحداث يونيو 2020 الرياضية في ألمانيا",
    "June 2020 sports events in Greece": "أحداث يونيو 2020 الرياضية في اليونان",
    "June 2020 sports events in Hungary": "أحداث يونيو 2020 الرياضية في المجر",
    "June 2020 sports events in India": "أحداث يونيو 2020 الرياضية في الهند",
    "June 2020 sports events in Indonesia": "أحداث يونيو 2020 الرياضية في إندونيسيا",
    "June 2020 sports events in Iran": "أحداث يونيو 2020 الرياضية في إيران",
    "June 2020 sports events in Ireland": "أحداث يونيو 2020 الرياضية في أيرلندا",
    "June 2020 sports events in Italy": "أحداث يونيو 2020 الرياضية في إيطاليا",
    "June 2020 sports events in Japan": "أحداث يونيو 2020 الرياضية في اليابان",
    "June 2020 sports events in Malaysia": "أحداث يونيو 2020 الرياضية في ماليزيا",
    "June 2020 sports events in Mexico": "أحداث يونيو 2020 الرياضية في المكسيك",
    "June 2020 sports events in Morocco": "أحداث يونيو 2020 الرياضية في المغرب",
    "June 2020 sports events in New Zealand": "أحداث يونيو 2020 الرياضية في نيوزيلندا",
    "June 2020 sports events in North America": "أحداث يونيو 2020 الرياضية في أمريكا الشمالية",
    "June 2020 sports events in Oceania": "أحداث يونيو 2020 الرياضية في أوقيانوسيا",
    "June 2020 sports events in Papua New Guinea": "أحداث يونيو 2020 الرياضية في بابوا غينيا الجديدة",
    "June 2020 sports events in Poland": "أحداث يونيو 2020 الرياضية في بولندا",
    "June 2020 sports events in Portugal": "أحداث يونيو 2020 الرياضية في البرتغال",
    "June 2020 sports events in Qatar": "أحداث يونيو 2020 الرياضية في قطر",
    "June 2020 sports events in Romania": "أحداث يونيو 2020 الرياضية في رومانيا",
    "June 2020 sports events in Russia": "أحداث يونيو 2020 الرياضية في روسيا",
    "June 2020 sports events in Saudi Arabia": "أحداث يونيو 2020 الرياضية في السعودية",
    "June 2020 sports events in Serbia": "أحداث يونيو 2020 الرياضية في صربيا",
    "June 2020 sports events in Singapore": "أحداث يونيو 2020 الرياضية في سنغافورة",
    "June 2020 sports events in Slovakia": "أحداث يونيو 2020 الرياضية في سلوفاكيا",
    "June 2020 sports events in South Africa": "أحداث يونيو 2020 الرياضية في جنوب إفريقيا",
    "June 2020 sports events in South America": "أحداث يونيو 2020 الرياضية في أمريكا الجنوبية",
    "June 2020 sports events in South Korea": "أحداث يونيو 2020 الرياضية في كوريا الجنوبية",
    "June 2020 sports events in Spain": "أحداث يونيو 2020 الرياضية في إسبانيا",
    "June 2020 sports events in Switzerland": "أحداث يونيو 2020 الرياضية في سويسرا",
    "June 2020 sports events in Taiwan": "أحداث يونيو 2020 الرياضية في تايوان",
    "June 2020 sports events in Thailand": "أحداث يونيو 2020 الرياضية في تايلاند",
    "June 2020 sports events in the Czech Republic": "أحداث يونيو 2020 الرياضية في التشيك",
    "June 2020 sports events in the Netherlands": "أحداث يونيو 2020 الرياضية في هولندا",
    "June 2020 sports events in the Philippines": "أحداث يونيو 2020 الرياضية في الفلبين",
    "June 2020 sports events in the United Kingdom": "أحداث يونيو 2020 الرياضية في المملكة المتحدة",
    "June 2020 sports events in the United States": "أحداث يونيو 2020 الرياضية في الولايات المتحدة",
    "June 2020 sports events in Tunisia": "أحداث يونيو 2020 الرياضية في تونس",
    "June 2020 sports events in Turkey": "أحداث يونيو 2020 الرياضية في تركيا",
    "June 2020 sports events in Ukraine": "أحداث يونيو 2020 الرياضية في أوكرانيا",
    "June 2020 sports events in Vietnam": "أحداث يونيو 2020 الرياضية في فيتنام",
    "june 2020 sports-events in austria": "أحداث يونيو 2020 الرياضية في النمسا",
    "june 2020 sports-events in canada": "أحداث يونيو 2020 الرياضية في كندا",
    "june 2020 sports-events in malaysia": "أحداث يونيو 2020 الرياضية في ماليزيا",
    "june 2020 sports-events in south america": "أحداث يونيو 2020 الرياضية في أمريكا الجنوبية",
    "june 2020 sports-events in the united states": "أحداث يونيو 2020 الرياضية في الولايات المتحدة",
    "March 2020 sports events in Africa": "أحداث مارس 2020 الرياضية في إفريقيا",
    "March 2020 sports events in Argentina": "أحداث مارس 2020 الرياضية في الأرجنتين",
    "March 2020 sports events in Asia": "أحداث مارس 2020 الرياضية في آسيا",
    "March 2020 sports events in Australia": "أحداث مارس 2020 الرياضية في أستراليا",
    "March 2020 sports events in Austria": "أحداث مارس 2020 الرياضية في النمسا",
    "March 2020 sports events in Bahrain": "أحداث مارس 2020 الرياضية في البحرين",
    "March 2020 sports events in Belgium": "أحداث مارس 2020 الرياضية في بلجيكا",
    "March 2020 sports events in Brazil": "أحداث مارس 2020 الرياضية في البرازيل",
    "March 2020 sports events in Bulgaria": "أحداث مارس 2020 الرياضية في بلغاريا",
    "March 2020 sports events in Canada": "أحداث مارس 2020 الرياضية في كندا",
    "March 2020 sports events in China": "أحداث مارس 2020 الرياضية في الصين",
    "March 2020 sports events in Costa Rica": "أحداث مارس 2020 الرياضية في كوستاريكا",
    "March 2020 sports events in Croatia": "أحداث مارس 2020 الرياضية في كرواتيا",
    "March 2020 sports events in Egypt": "أحداث مارس 2020 الرياضية في مصر",
    "March 2020 sports events in Europe": "أحداث مارس 2020 الرياضية في أوروبا",
    "March 2020 sports events in France": "أحداث مارس 2020 الرياضية في فرنسا",
    "March 2020 sports events in Germany": "أحداث مارس 2020 الرياضية في ألمانيا",
    "March 2020 sports events in Greece": "أحداث مارس 2020 الرياضية في اليونان",
    "March 2020 sports events in Hungary": "أحداث مارس 2020 الرياضية في المجر",
    "March 2020 sports events in India": "أحداث مارس 2020 الرياضية في الهند",
    "March 2020 sports events in Indonesia": "أحداث مارس 2020 الرياضية في إندونيسيا",
    "March 2020 sports events in Iran": "أحداث مارس 2020 الرياضية في إيران",
    "March 2020 sports events in Iraq": "أحداث مارس 2020 الرياضية في العراق",
    "March 2020 sports events in Ireland": "أحداث مارس 2020 الرياضية في أيرلندا",
    "March 2020 sports events in Italy": "أحداث مارس 2020 الرياضية في إيطاليا",
    "March 2020 sports events in Japan": "أحداث مارس 2020 الرياضية في اليابان",
    "March 2020 sports events in Kuwait": "أحداث مارس 2020 الرياضية في الكويت",
    "March 2020 sports events in Malaysia": "أحداث مارس 2020 الرياضية في ماليزيا",
    "March 2020 sports events in Mexico": "أحداث مارس 2020 الرياضية في المكسيك",
    "March 2020 sports events in New Zealand": "أحداث مارس 2020 الرياضية في نيوزيلندا",
    "March 2020 sports events in Nigeria": "أحداث مارس 2020 الرياضية في نيجيريا",
    "March 2020 sports events in North America": "أحداث مارس 2020 الرياضية في أمريكا الشمالية",
    "March 2020 sports events in Oceania": "أحداث مارس 2020 الرياضية في أوقيانوسيا",
    "March 2020 sports events in Pakistan": "أحداث مارس 2020 الرياضية في باكستان",
    "March 2020 sports events in Poland": "أحداث مارس 2020 الرياضية في بولندا",
    "March 2020 sports events in Portugal": "أحداث مارس 2020 الرياضية في البرتغال",
    "March 2020 sports events in Qatar": "أحداث مارس 2020 الرياضية في قطر",
    "March 2020 sports events in Romania": "أحداث مارس 2020 الرياضية في رومانيا",
    "March 2020 sports events in Russia": "أحداث مارس 2020 الرياضية في روسيا",
    "March 2020 sports events in Saudi Arabia": "أحداث مارس 2020 الرياضية في السعودية",
    "March 2020 sports events in Serbia": "أحداث مارس 2020 الرياضية في صربيا",
    "March 2020 sports events in Singapore": "أحداث مارس 2020 الرياضية في سنغافورة",
    "March 2020 sports events in Slovakia": "أحداث مارس 2020 الرياضية في سلوفاكيا",
    "March 2020 sports events in South Africa": "أحداث مارس 2020 الرياضية في جنوب إفريقيا",
    "March 2020 sports events in South America": "أحداث مارس 2020 الرياضية في أمريكا الجنوبية",
    "March 2020 sports events in South Korea": "أحداث مارس 2020 الرياضية في كوريا الجنوبية",
    "March 2020 sports events in Spain": "أحداث مارس 2020 الرياضية في إسبانيا",
    "March 2020 sports events in Switzerland": "أحداث مارس 2020 الرياضية في سويسرا",
    "March 2020 sports events in Taiwan": "أحداث مارس 2020 الرياضية في تايوان",
    "March 2020 sports events in Thailand": "أحداث مارس 2020 الرياضية في تايلاند",
    "March 2020 sports events in the Czech Republic": "أحداث مارس 2020 الرياضية في التشيك",
    "March 2020 sports events in the Netherlands": "أحداث مارس 2020 الرياضية في هولندا",
    "March 2020 sports events in the Philippines": "أحداث مارس 2020 الرياضية في الفلبين",
    "March 2020 sports events in the United Arab Emirates": "أحداث مارس 2020 الرياضية في الإمارات العربية المتحدة",
    "March 2020 sports events in the United Kingdom": "أحداث مارس 2020 الرياضية في المملكة المتحدة",
    "March 2020 sports events in the United States": "أحداث مارس 2020 الرياضية في الولايات المتحدة",
    "March 2020 sports events in Turkey": "أحداث مارس 2020 الرياضية في تركيا",
    "March 2020 sports events in Ukraine": "أحداث مارس 2020 الرياضية في أوكرانيا",
    "March 2020 sports events in Uzbekistan": "أحداث مارس 2020 الرياضية في أوزبكستان",
    "march 2020 sports-events in belgium": "أحداث مارس 2020 الرياضية في بلجيكا",
    "march 2020 sports-events in china": "أحداث مارس 2020 الرياضية في الصين",
    "march 2020 sports-events in europe": "أحداث مارس 2020 الرياضية في أوروبا",
    "march 2020 sports-events in mexico": "أحداث مارس 2020 الرياضية في المكسيك",
    "march 2020 sports-events in oceania": "أحداث مارس 2020 الرياضية في أوقيانوسيا",
    "march 2020 sports-events in thailand": "أحداث مارس 2020 الرياضية في تايلاند",
    "march 2020 sports-events in the united kingdom": "أحداث مارس 2020 الرياضية في المملكة المتحدة",
    "May 2020 sports events in Africa": "أحداث مايو 2020 الرياضية في إفريقيا",
    "May 2020 sports events in Algeria": "أحداث مايو 2020 الرياضية في الجزائر",
    "May 2020 sports events in Argentina": "أحداث مايو 2020 الرياضية في الأرجنتين",
    "May 2020 sports events in Asia": "أحداث مايو 2020 الرياضية في آسيا",
    "May 2020 sports events in Australia": "أحداث مايو 2020 الرياضية في أستراليا",
    "May 2020 sports events in Austria": "أحداث مايو 2020 الرياضية في النمسا",
    "May 2020 sports events in Azerbaijan": "أحداث مايو 2020 الرياضية في أذربيجان",
    "May 2020 sports events in Bahrain": "أحداث مايو 2020 الرياضية في البحرين",
    "May 2020 sports events in Belgium": "أحداث مايو 2020 الرياضية في بلجيكا",
    "May 2020 sports events in Brazil": "أحداث مايو 2020 الرياضية في البرازيل",
    "May 2020 sports events in Bulgaria": "أحداث مايو 2020 الرياضية في بلغاريا",
    "May 2020 sports events in Canada": "أحداث مايو 2020 الرياضية في كندا",
    "May 2020 sports events in China": "أحداث مايو 2020 الرياضية في الصين",
    "May 2020 sports events in Costa Rica": "أحداث مايو 2020 الرياضية في كوستاريكا",
    "May 2020 sports events in Croatia": "أحداث مايو 2020 الرياضية في كرواتيا",
    "May 2020 sports events in Egypt": "أحداث مايو 2020 الرياضية في مصر",
    "May 2020 sports events in Europe": "أحداث مايو 2020 الرياضية في أوروبا",
    "May 2020 sports events in France": "أحداث مايو 2020 الرياضية في فرنسا",
    "May 2020 sports events in Germany": "أحداث مايو 2020 الرياضية في ألمانيا",
    "May 2020 sports events in Greece": "أحداث مايو 2020 الرياضية في اليونان",
    "May 2020 sports events in Hungary": "أحداث مايو 2020 الرياضية في المجر",
    "May 2020 sports events in India": "أحداث مايو 2020 الرياضية في الهند",
    "May 2020 sports events in Indonesia": "أحداث مايو 2020 الرياضية في إندونيسيا",
    "May 2020 sports events in Iran": "أحداث مايو 2020 الرياضية في إيران",
    "May 2020 sports events in Ireland": "أحداث مايو 2020 الرياضية في أيرلندا",
    "May 2020 sports events in Italy": "أحداث مايو 2020 الرياضية في إيطاليا",
    "May 2020 sports events in Japan": "أحداث مايو 2020 الرياضية في اليابان",
    "May 2020 sports events in Malaysia": "أحداث مايو 2020 الرياضية في ماليزيا",
    "May 2020 sports events in Mexico": "أحداث مايو 2020 الرياضية في المكسيك",
    "May 2020 sports events in Morocco": "أحداث مايو 2020 الرياضية في المغرب",
    "May 2020 sports events in New Zealand": "أحداث مايو 2020 الرياضية في نيوزيلندا",
    "May 2020 sports events in North America": "أحداث مايو 2020 الرياضية في أمريكا الشمالية",
    "May 2020 sports events in Oceania": "أحداث مايو 2020 الرياضية في أوقيانوسيا",
    "May 2020 sports events in Pakistan": "أحداث مايو 2020 الرياضية في باكستان",
    "May 2020 sports events in Papua New Guinea": "أحداث مايو 2020 الرياضية في بابوا غينيا الجديدة",
    "May 2020 sports events in Poland": "أحداث مايو 2020 الرياضية في بولندا",
    "May 2020 sports events in Portugal": "أحداث مايو 2020 الرياضية في البرتغال",
    "May 2020 sports events in Romania": "أحداث مايو 2020 الرياضية في رومانيا",
    "May 2020 sports events in Russia": "أحداث مايو 2020 الرياضية في روسيا",
    "May 2020 sports events in Saudi Arabia": "أحداث مايو 2020 الرياضية في السعودية",
    "May 2020 sports events in Serbia": "أحداث مايو 2020 الرياضية في صربيا",
    "May 2020 sports events in Singapore": "أحداث مايو 2020 الرياضية في سنغافورة",
    "May 2020 sports events in Slovakia": "أحداث مايو 2020 الرياضية في سلوفاكيا",
    "May 2020 sports events in South Africa": "أحداث مايو 2020 الرياضية في جنوب إفريقيا",
    "May 2020 sports events in South America": "أحداث مايو 2020 الرياضية في أمريكا الجنوبية",
    "May 2020 sports events in South Korea": "أحداث مايو 2020 الرياضية في كوريا الجنوبية",
    "May 2020 sports events in Spain": "أحداث مايو 2020 الرياضية في إسبانيا",
    "May 2020 sports events in Switzerland": "أحداث مايو 2020 الرياضية في سويسرا",
    "May 2020 sports events in Taiwan": "أحداث مايو 2020 الرياضية في تايوان",
    "May 2020 sports events in Thailand": "أحداث مايو 2020 الرياضية في تايلاند",
    "May 2020 sports events in the Czech Republic": "أحداث مايو 2020 الرياضية في التشيك",
    "May 2020 sports events in the Netherlands": "أحداث مايو 2020 الرياضية في هولندا",
    "May 2020 sports events in the Philippines": "أحداث مايو 2020 الرياضية في الفلبين",
    "May 2020 sports events in the United Arab Emirates": "أحداث مايو 2020 الرياضية في الإمارات العربية المتحدة",
    "May 2020 sports events in the United Kingdom": "أحداث مايو 2020 الرياضية في المملكة المتحدة",
    "May 2020 sports events in the United States": "أحداث مايو 2020 الرياضية في الولايات المتحدة",
    "May 2020 sports events in Tunisia": "أحداث مايو 2020 الرياضية في تونس",
    "May 2020 sports events in Turkey": "أحداث مايو 2020 الرياضية في تركيا",
    "May 2020 sports events in Ukraine": "أحداث مايو 2020 الرياضية في أوكرانيا",
    "May 2020 sports events in Uzbekistan": "أحداث مايو 2020 الرياضية في أوزبكستان",
    "May 2020 sports events in Vietnam": "أحداث مايو 2020 الرياضية في فيتنام",
    "may 2020 sports-events in africa": "أحداث مايو 2020 الرياضية في إفريقيا",
    "may 2020 sports-events in asia": "أحداث مايو 2020 الرياضية في آسيا",
    "may 2020 sports-events in europe": "أحداث مايو 2020 الرياضية في أوروبا",
    "may 2020 sports-events in switzerland": "أحداث مايو 2020 الرياضية في سويسرا",
    "may 2020 sports-events in united states": "أحداث مايو 2020 الرياضية في الولايات المتحدة",
    "November 2020 sports events in Africa": "أحداث نوفمبر 2020 الرياضية في إفريقيا",
    "November 2020 sports events in Argentina": "أحداث نوفمبر 2020 الرياضية في الأرجنتين",
    "November 2020 sports events in Asia": "أحداث نوفمبر 2020 الرياضية في آسيا",
    "November 2020 sports events in Australia": "أحداث نوفمبر 2020 الرياضية في أستراليا",
    "November 2020 sports events in Austria": "أحداث نوفمبر 2020 الرياضية في النمسا",
    "November 2020 sports events in Bahrain": "أحداث نوفمبر 2020 الرياضية في البحرين",
    "November 2020 sports events in Bangladesh": "أحداث نوفمبر 2020 الرياضية في بنغلاديش",
    "November 2020 sports events in Brazil": "أحداث نوفمبر 2020 الرياضية في البرازيل",
    "November 2020 sports events in Bulgaria": "أحداث نوفمبر 2020 الرياضية في بلغاريا",
    "November 2020 sports events in Canada": "أحداث نوفمبر 2020 الرياضية في كندا",
    "November 2020 sports events in China": "أحداث نوفمبر 2020 الرياضية في الصين",
    "November 2020 sports events in Croatia": "أحداث نوفمبر 2020 الرياضية في كرواتيا",
    "November 2020 sports events in Egypt": "أحداث نوفمبر 2020 الرياضية في مصر",
    "November 2020 sports events in Europe": "أحداث نوفمبر 2020 الرياضية في أوروبا",
    "November 2020 sports events in France": "أحداث نوفمبر 2020 الرياضية في فرنسا",
    "November 2020 sports events in Germany": "أحداث نوفمبر 2020 الرياضية في ألمانيا",
    "November 2020 sports events in Hungary": "أحداث نوفمبر 2020 الرياضية في المجر",
    "November 2020 sports events in India": "أحداث نوفمبر 2020 الرياضية في الهند",
    "November 2020 sports events in Indonesia": "أحداث نوفمبر 2020 الرياضية في إندونيسيا",
    "November 2020 sports events in Iran": "أحداث نوفمبر 2020 الرياضية في إيران",
    "November 2020 sports events in Iraq": "أحداث نوفمبر 2020 الرياضية في العراق",
    "November 2020 sports events in Ireland": "أحداث نوفمبر 2020 الرياضية في أيرلندا",
    "November 2020 sports events in Italy": "أحداث نوفمبر 2020 الرياضية في إيطاليا",
    "November 2020 sports events in Japan": "أحداث نوفمبر 2020 الرياضية في اليابان",
    "November 2020 sports events in Malaysia": "أحداث نوفمبر 2020 الرياضية في ماليزيا",
    "November 2020 sports events in Mexico": "أحداث نوفمبر 2020 الرياضية في المكسيك",
    "November 2020 sports events in New Zealand": "أحداث نوفمبر 2020 الرياضية في نيوزيلندا",
    "November 2020 sports events in North America": "أحداث نوفمبر 2020 الرياضية في أمريكا الشمالية",
    "November 2020 sports events in Oceania": "أحداث نوفمبر 2020 الرياضية في أوقيانوسيا",
    "November 2020 sports events in Pakistan": "أحداث نوفمبر 2020 الرياضية في باكستان",
    "November 2020 sports events in Poland": "أحداث نوفمبر 2020 الرياضية في بولندا",
    "November 2020 sports events in Portugal": "أحداث نوفمبر 2020 الرياضية في البرتغال",
    "November 2020 sports events in Qatar": "أحداث نوفمبر 2020 الرياضية في قطر",
    "November 2020 sports events in Romania": "أحداث نوفمبر 2020 الرياضية في رومانيا",
    "November 2020 sports events in Russia": "أحداث نوفمبر 2020 الرياضية في روسيا",
    "November 2020 sports events in Saudi Arabia": "أحداث نوفمبر 2020 الرياضية في السعودية",
    "November 2020 sports events in Serbia": "أحداث نوفمبر 2020 الرياضية في صربيا",
    "November 2020 sports events in Singapore": "أحداث نوفمبر 2020 الرياضية في سنغافورة",
    "November 2020 sports events in South Africa": "أحداث نوفمبر 2020 الرياضية في جنوب إفريقيا",
    "November 2020 sports events in South America": "أحداث نوفمبر 2020 الرياضية في أمريكا الجنوبية",
    "November 2020 sports events in South Korea": "أحداث نوفمبر 2020 الرياضية في كوريا الجنوبية",
    "November 2020 sports events in Spain": "أحداث نوفمبر 2020 الرياضية في إسبانيا",
    "November 2020 sports events in Switzerland": "أحداث نوفمبر 2020 الرياضية في سويسرا",
    "November 2020 sports events in Thailand": "أحداث نوفمبر 2020 الرياضية في تايلاند",
    "November 2020 sports events in the Czech Republic": "أحداث نوفمبر 2020 الرياضية في التشيك",
    "November 2020 sports events in the Netherlands": "أحداث نوفمبر 2020 الرياضية في هولندا",
    "November 2020 sports events in the Philippines": "أحداث نوفمبر 2020 الرياضية في الفلبين",
    "November 2020 sports events in the United Arab Emirates": "أحداث نوفمبر 2020 الرياضية في الإمارات العربية المتحدة",
    "November 2020 sports events in the United Kingdom": "أحداث نوفمبر 2020 الرياضية في المملكة المتحدة",
    "November 2020 sports events in the United States": "أحداث نوفمبر 2020 الرياضية في الولايات المتحدة",
    "November 2020 sports events in Turkey": "أحداث نوفمبر 2020 الرياضية في تركيا",
    "November 2020 sports events in Ukraine": "أحداث نوفمبر 2020 الرياضية في أوكرانيا",
    "november 2020 sports-events in canada": "أحداث نوفمبر 2020 الرياضية في كندا",
    "november 2020 sports-events in europe": "أحداث نوفمبر 2020 الرياضية في أوروبا",
    "november 2020 sports-events in germany": "أحداث نوفمبر 2020 الرياضية في ألمانيا",
    "november 2020 sports-events in north america": "أحداث نوفمبر 2020 الرياضية في أمريكا الشمالية",
    "november 2020 sports-events in oceania": "أحداث نوفمبر 2020 الرياضية في أوقيانوسيا",
    "november 2020 sports-events in the united states": "أحداث نوفمبر 2020 الرياضية في الولايات المتحدة",
    "november 2020 sports-events in united kingdom": "أحداث نوفمبر 2020 الرياضية في المملكة المتحدة",
    "October 2020 sports events in Africa": "أحداث أكتوبر 2020 الرياضية في إفريقيا",
    "October 2020 sports events in Argentina": "أحداث أكتوبر 2020 الرياضية في الأرجنتين",
    "October 2020 sports events in Asia": "أحداث أكتوبر 2020 الرياضية في آسيا",
    "October 2020 sports events in Australia": "أحداث أكتوبر 2020 الرياضية في أستراليا",
    "October 2020 sports events in Austria": "أحداث أكتوبر 2020 الرياضية في النمسا",
    "October 2020 sports events in Bahrain": "أحداث أكتوبر 2020 الرياضية في البحرين",
    "October 2020 sports events in Bangladesh": "أحداث أكتوبر 2020 الرياضية في بنغلاديش",
    "October 2020 sports events in Belgium": "أحداث أكتوبر 2020 الرياضية في بلجيكا",
    "October 2020 sports events in Brazil": "أحداث أكتوبر 2020 الرياضية في البرازيل",
    "October 2020 sports events in Bulgaria": "أحداث أكتوبر 2020 الرياضية في بلغاريا",
    "October 2020 sports events in Canada": "أحداث أكتوبر 2020 الرياضية في كندا",
    "October 2020 sports events in Chile": "أحداث أكتوبر 2020 الرياضية في تشيلي",
    "October 2020 sports events in China": "أحداث أكتوبر 2020 الرياضية في الصين",
    "October 2020 sports events in Croatia": "أحداث أكتوبر 2020 الرياضية في كرواتيا",
    "October 2020 sports events in Egypt": "أحداث أكتوبر 2020 الرياضية في مصر",
    "October 2020 sports events in Europe": "أحداث أكتوبر 2020 الرياضية في أوروبا",
    "October 2020 sports events in Fiji": "أحداث أكتوبر 2020 الرياضية في فيجي",
    "October 2020 sports events in France": "أحداث أكتوبر 2020 الرياضية في فرنسا",
    "October 2020 sports events in Germany": "أحداث أكتوبر 2020 الرياضية في ألمانيا",
    "October 2020 sports events in Greece": "أحداث أكتوبر 2020 الرياضية في اليونان",
    "October 2020 sports events in Hungary": "أحداث أكتوبر 2020 الرياضية في المجر",
    "October 2020 sports events in India": "أحداث أكتوبر 2020 الرياضية في الهند",
    "October 2020 sports events in Indonesia": "أحداث أكتوبر 2020 الرياضية في إندونيسيا",
    "October 2020 sports events in Iran": "أحداث أكتوبر 2020 الرياضية في إيران",
    "October 2020 sports events in Ireland": "أحداث أكتوبر 2020 الرياضية في أيرلندا",
    "October 2020 sports events in Italy": "أحداث أكتوبر 2020 الرياضية في إيطاليا",
    "October 2020 sports events in Japan": "أحداث أكتوبر 2020 الرياضية في اليابان",
    "October 2020 sports events in Malaysia": "أحداث أكتوبر 2020 الرياضية في ماليزيا",
    "October 2020 sports events in Mexico": "أحداث أكتوبر 2020 الرياضية في المكسيك",
    "October 2020 sports events in New Zealand": "أحداث أكتوبر 2020 الرياضية في نيوزيلندا",
    "October 2020 sports events in Nigeria": "أحداث أكتوبر 2020 الرياضية في نيجيريا",
    "October 2020 sports events in North America": "أحداث أكتوبر 2020 الرياضية في أمريكا الشمالية",
    "October 2020 sports events in Oceania": "أحداث أكتوبر 2020 الرياضية في أوقيانوسيا",
    "October 2020 sports events in Pakistan": "أحداث أكتوبر 2020 الرياضية في باكستان",
    "October 2020 sports events in Peru": "أحداث أكتوبر 2020 الرياضية في بيرو",
    "October 2020 sports events in Poland": "أحداث أكتوبر 2020 الرياضية في بولندا",
    "October 2020 sports events in Portugal": "أحداث أكتوبر 2020 الرياضية في البرتغال",
    "October 2020 sports events in Qatar": "أحداث أكتوبر 2020 الرياضية في قطر",
    "October 2020 sports events in Romania": "أحداث أكتوبر 2020 الرياضية في رومانيا",
    "October 2020 sports events in Russia": "أحداث أكتوبر 2020 الرياضية في روسيا",
    "October 2020 sports events in Saudi Arabia": "أحداث أكتوبر 2020 الرياضية في السعودية",
    "October 2020 sports events in Serbia": "أحداث أكتوبر 2020 الرياضية في صربيا",
    "October 2020 sports events in Singapore": "أحداث أكتوبر 2020 الرياضية في سنغافورة",
    "October 2020 sports events in Slovakia": "أحداث أكتوبر 2020 الرياضية في سلوفاكيا",
    "October 2020 sports events in South Africa": "أحداث أكتوبر 2020 الرياضية في جنوب إفريقيا",
    "October 2020 sports events in South America": "أحداث أكتوبر 2020 الرياضية في أمريكا الجنوبية",
    "October 2020 sports events in South Korea": "أحداث أكتوبر 2020 الرياضية في كوريا الجنوبية",
    "October 2020 sports events in Spain": "أحداث أكتوبر 2020 الرياضية في إسبانيا",
    "October 2020 sports events in Switzerland": "أحداث أكتوبر 2020 الرياضية في سويسرا",
    "October 2020 sports events in Taiwan": "أحداث أكتوبر 2020 الرياضية في تايوان",
    "October 2020 sports events in Thailand": "أحداث أكتوبر 2020 الرياضية في تايلاند",
    "October 2020 sports events in the Czech Republic": "أحداث أكتوبر 2020 الرياضية في التشيك",
    "October 2020 sports events in the Netherlands": "أحداث أكتوبر 2020 الرياضية في هولندا",
    "October 2020 sports events in the Philippines": "أحداث أكتوبر 2020 الرياضية في الفلبين",
    "October 2020 sports events in the United Arab Emirates": "أحداث أكتوبر 2020 الرياضية في الإمارات العربية المتحدة",
    "October 2020 sports events in the United Kingdom": "أحداث أكتوبر 2020 الرياضية في المملكة المتحدة",
    "October 2020 sports events in the United States": "أحداث أكتوبر 2020 الرياضية في الولايات المتحدة",
    "October 2020 sports events in Tunisia": "أحداث أكتوبر 2020 الرياضية في تونس",
    "October 2020 sports events in Turkey": "أحداث أكتوبر 2020 الرياضية في تركيا",
    "october 2020 sports-events in africa": "أحداث أكتوبر 2020 الرياضية في إفريقيا",
    "october 2020 sports-events in france": "أحداث أكتوبر 2020 الرياضية في فرنسا",
    "october 2020 sports-events in oceania": "أحداث أكتوبر 2020 الرياضية في أوقيانوسيا",
    "october 2020 sports-events in poland": "أحداث أكتوبر 2020 الرياضية في بولندا",
    "october 2020 sports-events in the united states": "أحداث أكتوبر 2020 الرياضية في الولايات المتحدة",
    "october 2020 sports-events": "أحداث أكتوبر 2020 الرياضية",
    "September 2020 sports events in Africa": "أحداث سبتمبر 2020 الرياضية في إفريقيا",
    "September 2020 sports events in Argentina": "أحداث سبتمبر 2020 الرياضية في الأرجنتين",
    "September 2020 sports events in Asia": "أحداث سبتمبر 2020 الرياضية في آسيا",
    "September 2020 sports events in Australia": "أحداث سبتمبر 2020 الرياضية في أستراليا",
    "September 2020 sports events in Austria": "أحداث سبتمبر 2020 الرياضية في النمسا",
    "September 2020 sports events in Azerbaijan": "أحداث سبتمبر 2020 الرياضية في أذربيجان",
    "September 2020 sports events in Bangladesh": "أحداث سبتمبر 2020 الرياضية في بنغلاديش",
    "September 2020 sports events in Belgium": "أحداث سبتمبر 2020 الرياضية في بلجيكا",
    "September 2020 sports events in Brazil": "أحداث سبتمبر 2020 الرياضية في البرازيل",
    "September 2020 sports events in Bulgaria": "أحداث سبتمبر 2020 الرياضية في بلغاريا",
    "September 2020 sports events in Canada": "أحداث سبتمبر 2020 الرياضية في كندا",
    "September 2020 sports events in China": "أحداث سبتمبر 2020 الرياضية في الصين",
    "September 2020 sports events in Croatia": "أحداث سبتمبر 2020 الرياضية في كرواتيا",
    "September 2020 sports events in Egypt": "أحداث سبتمبر 2020 الرياضية في مصر",
    "September 2020 sports events in Europe": "أحداث سبتمبر 2020 الرياضية في أوروبا",
    "September 2020 sports events in Fiji": "أحداث سبتمبر 2020 الرياضية في فيجي",
    "September 2020 sports events in France": "أحداث سبتمبر 2020 الرياضية في فرنسا",
    "September 2020 sports events in Germany": "أحداث سبتمبر 2020 الرياضية في ألمانيا",
    "September 2020 sports events in Greece": "أحداث سبتمبر 2020 الرياضية في اليونان",
    "September 2020 sports events in Hungary": "أحداث سبتمبر 2020 الرياضية في المجر",
    "September 2020 sports events in India": "أحداث سبتمبر 2020 الرياضية في الهند",
    "September 2020 sports events in Indonesia": "أحداث سبتمبر 2020 الرياضية في إندونيسيا",
    "September 2020 sports events in Iran": "أحداث سبتمبر 2020 الرياضية في إيران",
    "September 2020 sports events in Iraq": "أحداث سبتمبر 2020 الرياضية في العراق",
    "September 2020 sports events in Ireland": "أحداث سبتمبر 2020 الرياضية في أيرلندا",
    "September 2020 sports events in Italy": "أحداث سبتمبر 2020 الرياضية في إيطاليا",
    "September 2020 sports events in Japan": "أحداث سبتمبر 2020 الرياضية في اليابان",
    "September 2020 sports events in Lebanon": "أحداث سبتمبر 2020 الرياضية في لبنان",
    "September 2020 sports events in Malaysia": "أحداث سبتمبر 2020 الرياضية في ماليزيا",
    "September 2020 sports events in Mexico": "أحداث سبتمبر 2020 الرياضية في المكسيك",
    "September 2020 sports events in Morocco": "أحداث سبتمبر 2020 الرياضية في المغرب",
    "September 2020 sports events in New Zealand": "أحداث سبتمبر 2020 الرياضية في نيوزيلندا",
    "September 2020 sports events in Nigeria": "أحداث سبتمبر 2020 الرياضية في نيجيريا",
    "September 2020 sports events in North America": "أحداث سبتمبر 2020 الرياضية في أمريكا الشمالية",
    "September 2020 sports events in Oceania": "أحداث سبتمبر 2020 الرياضية في أوقيانوسيا",
    "September 2020 sports events in Pakistan": "أحداث سبتمبر 2020 الرياضية في باكستان",
    "September 2020 sports events in Peru": "أحداث سبتمبر 2020 الرياضية في بيرو",
    "September 2020 sports events in Poland": "أحداث سبتمبر 2020 الرياضية في بولندا",
    "September 2020 sports events in Portugal": "أحداث سبتمبر 2020 الرياضية في البرتغال",
    "September 2020 sports events in Qatar": "أحداث سبتمبر 2020 الرياضية في قطر",
    "September 2020 sports events in Romania": "أحداث سبتمبر 2020 الرياضية في رومانيا",
    "September 2020 sports events in Russia": "أحداث سبتمبر 2020 الرياضية في روسيا",
    "September 2020 sports events in Serbia": "أحداث سبتمبر 2020 الرياضية في صربيا",
    "September 2020 sports events in Singapore": "أحداث سبتمبر 2020 الرياضية في سنغافورة",
    "September 2020 sports events in Slovakia": "أحداث سبتمبر 2020 الرياضية في سلوفاكيا",
    "September 2020 sports events in South Africa": "أحداث سبتمبر 2020 الرياضية في جنوب إفريقيا",
    "September 2020 sports events in South America": "أحداث سبتمبر 2020 الرياضية في أمريكا الجنوبية",
    "September 2020 sports events in South Korea": "أحداث سبتمبر 2020 الرياضية في كوريا الجنوبية",
    "September 2020 sports events in Spain": "أحداث سبتمبر 2020 الرياضية في إسبانيا",
    "September 2020 sports events in Switzerland": "أحداث سبتمبر 2020 الرياضية في سويسرا",
    "September 2020 sports events in Taiwan": "أحداث سبتمبر 2020 الرياضية في تايوان",
    "September 2020 sports events in Thailand": "أحداث سبتمبر 2020 الرياضية في تايلاند",
    "September 2020 sports events in the Czech Republic": "أحداث سبتمبر 2020 الرياضية في التشيك",
    "September 2020 sports events in the Netherlands": "أحداث سبتمبر 2020 الرياضية في هولندا",
    "September 2020 sports events in the Philippines": "أحداث سبتمبر 2020 الرياضية في الفلبين",
    "September 2020 sports events in the Solomon Islands": "أحداث سبتمبر 2020 الرياضية في جزر سليمان",
    "September 2020 sports events in the United Arab Emirates": "أحداث سبتمبر 2020 الرياضية في الإمارات العربية المتحدة",
    "September 2020 sports events in the United Kingdom": "أحداث سبتمبر 2020 الرياضية في المملكة المتحدة",
    "September 2020 sports events in the United States": "أحداث سبتمبر 2020 الرياضية في الولايات المتحدة",
    "September 2020 sports events in Trinidad and Tobago": "أحداث سبتمبر 2020 الرياضية في ترينيداد وتوباغو",
    "September 2020 sports events in Tunisia": "أحداث سبتمبر 2020 الرياضية في تونس",
    "September 2020 sports events in Turkey": "أحداث سبتمبر 2020 الرياضية في تركيا",
    "September 2020 sports events in Ukraine": "أحداث سبتمبر 2020 الرياضية في أوكرانيا",
    "september 2020 sports-events in germany": "أحداث سبتمبر 2020 الرياضية في ألمانيا",
    "september 2020 sports-events in japan": "أحداث سبتمبر 2020 الرياضية في اليابان",
    "september 2020 sports-events in new zealand": "أحداث سبتمبر 2020 الرياضية في نيوزيلندا",
    "september 2020 sports-events in north america": "أحداث سبتمبر 2020 الرياضية في أمريكا الشمالية",
    "september 2020 sports-events in turkey": "أحداث سبتمبر 2020 الرياضية في تركيا",
    "september 2020 sports-events": "أحداث سبتمبر 2020 الرياضية",
}

fast_data_2 = {
    # "Entertainment at sports events": "ترفيه في أحداث رياضية",
    "Sports events cancelled due to the COVID-19 pandemic": "أحداث رياضية ألغيت بسبب جائحة فيروس كورونا",
    "Sports events cancelled due to the Russian invasion of Ukraine": "أحداث رياضية ألغيت بسبب الغزو الروسي لأوكرانيا",
    "Sports events curtailed and voided due to the COVID-19 pandemic": "أحداث رياضية اختصرت وألغيت بسبب جائحة فيروس كورونا",
    "Sports events curtailed due to the COVID-19 pandemic": "أحداث رياضية اختصرت بسبب جائحة فيروس كورونا",
    "Sports events in Africa": "أحداث رياضية في إفريقيا",
    "Sports events in Asia": "أحداث رياضية في آسيا",
    "Sports events in Attica": "أحداث رياضية في أتيكا",
    "Sports events in Bucharest": "أحداث رياضية في بوخارست",
    "Sports events in Cardiff": "أحداث رياضية في كارديف",
    "Sports events in Central Macedonia": "أحداث رياضية في إقليم مقدونيا الوسطى",
    "Sports events in Europe": "أحداث رياضية في أوروبا",
    "Sports events in North America": "أحداث رياضية في أمريكا الشمالية",
    "Sports events in Oceania": "أحداث رياضية في أوقيانوسيا",
    "Sports events in Ponce, Puerto Rico": "أحداث رياضية في بونس، بورتوريكو",
    "Sports events in South America": "أحداث رياضية في أمريكا الجنوبية",
    "Sports events in Western Greece": "أحداث رياضية في غرب اليونان",
    "Sports events postponed due to the COVID-19 pandemic": "أحداث رياضية تأجلت بسبب جائحة فيروس كورونا",
}

to_test = [
    ("test_sports_events_1", fast_data_1),
    ("test_sports_events_2", fast_data_2),
]


@pytest.mark.parametrize("category, expected", fast_data_1.items(), ids=fast_data_1.keys())
@pytest.mark.fast
def test_2_fast_data_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", fast_data_2.items(), ids=fast_data_2.keys())
@pytest.mark.fast
def test_2_fast_data_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""
Country Label Bot Module
"""

import functools
import re

from ...config import app_settings
from ...fix import fixtitle
from ...helps import logger
from ...new_resolvers.reslove_all import new_resolvers_all
from ...time_resolvers.time_to_arabic import convert_time_to_arabic
from ...translations import (
    SPORTS_KEYS_FOR_LABEL,
    Nat_mens,
    New_female_keys,
    get_from_pf_keys2,
    jobs_mens_data,
    pop_of_without_in,
    religious_entries,
)
from .. import sport_lab_suffixes, team_work, with_years_bot
from ..films_and_others_bot import te_films
from ..ma_bots2.country2_label_bot import country_2_title_work
from ..make_bots.bot_2018 import get_pop_All_18
from ..make_bots.reg_lines import RE1_compile, RE2_compile, RE3_compile
from ..matables_bots.table1_bot import get_KAKO
from ..o_bots import parties_bot, univer
from ..o_bots.peoples_resolver import work_peoples
from . import ye_ts_bot


@functools.lru_cache(maxsize=10000)
def get_lab_for_country2(country: str) -> str:
    """
    TODO: should be moved to functions directory.
    Retrieve laboratory information for a specified country.
    """

    country2 = country.lower().strip()

    resolved_label = (
        new_resolvers_all(country2)
        or get_from_pf_keys2(country2)
        or get_pop_All_18(country2)
        or te_films(country2)
        or sport_lab_suffixes.get_teams_new(country2)
        or parties_bot.get_parties_lab(country2)
        or team_work.Get_team_work_Club(country2)
        or univer.te_universities(country2)
        or work_peoples(country2)
        or get_KAKO(country2)
        or convert_time_to_arabic(country2)
        or get_pop_All_18(country2)
        or ""
    )
    logger.info(f'>> get_lab_for_country2 "{country2}": label: {resolved_label}')

    return resolved_label


@functools.lru_cache(maxsize=None)
def Get_country2(country: str) -> str:
    """
    TODO: should be moved to functions directory.
    Retrieve information related to a specified country.
    """

    normalized_country = country.lower().strip()
    logger.info(f'>> Get_country2 "{normalized_country}":')

    resolved_label = (
        country_2_title_work(country, with_years=True)
        or get_lab_for_country2(country)
        or ye_ts_bot.translate_general_category(normalized_country, start_get_country2=False, fix_title=False)
        or get_pop_All_18(normalized_country.lower(), "")
        or ""
    )

    if resolved_label:
        resolved_label = fixtitle.fixlabel(resolved_label, en=normalized_country)

    resolved_label = " ".join(resolved_label.strip().split())

    logger.info(f'>> Get_country2 "{normalized_country}": cnt_la: {resolved_label}')

    return resolved_label


@functools.lru_cache(maxsize=10000)
def _resolve_remainder(remainder: str) -> str:
    """Helper to resolve the label for the remainder of a string."""
    label = (
        Get_country2(remainder)
        or get_lab_for_country2(remainder)
        or ye_ts_bot.translate_general_category(remainder, fix_title=False)
        or ""
    )
    return label


def _validate_separators(country: str) -> bool:
    """Check if the country string contains invalid separators."""
    separators = [
        "based in",
        "in",
        "by",
        "about",
        "to",
        "of",
        "-of ",  # special case
        "from",
        "at",
        "on",
    ]
    separators = [f" {sep} " if sep != "-of " else sep for sep in separators]
    for sep in separators:
        if sep in country:
            return False
    return True


def check_historical_prefixes(country: str) -> str:
    """Check for historical prefixes."""
    historical_prefixes = {
        "defunct national": "{} وطنية سابقة",
    }
    country = country.lower().strip()
    if not _validate_separators(country):
        return ""

    for prefix, prefix_template in historical_prefixes.items():
        if country.startswith(f"{prefix} "):
            logger.debug(f">>> country.startswith({prefix})")
            remainder = country[len(prefix) :].strip()
            remainder_label = _resolve_remainder(remainder)

            if remainder_label:
                resolved_label = prefix_template.format(remainder_label)
                if remainder_label.strip().endswith(" في") and prefix.startswith("defunct "):
                    resolved_label = f"{remainder_label.strip()[: -len(' في')]} سابقة في"
                logger.info(f'>>>>>> cdcdc new cnt_la  "{resolved_label}" ')
                return resolved_label
    return ""


class CountryLabelRetriever:
    """
    A class to handle the retrieval of country labels and related terms.
    """

    def __init__(self) -> None:
        pass

    @functools.lru_cache(maxsize=1024)
    def get_country_label(self, country: str, start_get_country2: bool = True) -> str:
        """Retrieve the label for a given country name."""
        country = country.lower()

        logger.debug(">> ----------------- get_country start ----------------- ")
        logger.debug(f"<<yellow>> start get_country_label: {country=}")

        resolved_label = self._check_basic_lookups(country)

        if resolved_label == "" and start_get_country2:
            resolved_label = Get_country2(country)

        if not resolved_label:
            resolved_label = (
                _resolve_remainder(country)
                or self._check_prefixes(country)
                or check_historical_prefixes(country)
                or new_resolvers_all(country)
                or self._check_regex_years(country)
                or self._check_members(country)
                or SPORTS_KEYS_FOR_LABEL.get(country, "")
                or ""
            )

        if resolved_label:
            if "سنوات في القرن" in resolved_label:
                resolved_label = re.sub(r"سنوات في القرن", "سنوات القرن", resolved_label)

        logger.info_if_or_debug(f"<<yellow>> end get_country_label: {country=}, {resolved_label=}", resolved_label)
        return resolved_label

    def _check_basic_lookups(self, country: str) -> str:
        """Check basic lookup tables and functions."""
        if country.strip().isdigit():
            return country

        label = (
            New_female_keys.get(country, "")
            or religious_entries.get(country, "")
            or te_films(country)
            or new_resolvers_all(country)
            or team_work.Get_team_work_Club(country)
        )
        return label

    def _check_prefixes(self, country: str) -> str:
        """Check for specific prefixes like women's, men's, etc."""
        prefix_labels = {
            "women's ": "نسائية",
            "men's ": "رجالية",
        }

        for prefix, prefix_label in prefix_labels.items():
            if country.startswith(prefix):
                logger.debug(f">>> country.startswith({prefix})")
                remainder = country[len(prefix) :]
                remainder_label = _resolve_remainder(remainder)

                if remainder_label:
                    new_label = f"{remainder_label} {prefix_label}"
                    logger.info(f'>>>>>> xxx new cnt_la  "{new_label}" ')
                    return new_label

        return ""

    def _check_regex_years(self, country: str) -> str:
        """Check regex patterns for years."""
        RE1 = RE1_compile.match(country)
        RE2 = RE2_compile.match(country)
        RE3 = RE3_compile.match(country)

        if RE1 or RE2 or RE3:
            return with_years_bot.Try_With_Years(country)
        return ""

    def _check_members(self, country: str) -> str:
        """Check for 'members of' pattern."""
        if country.endswith(" members of"):
            country2 = country.replace(" members of", "")
            resolved_label = Nat_mens.get(country2, "")
            if resolved_label:
                resolved_label = f"{resolved_label} أعضاء في  "
                logger.info(f"a<<lightblue>>>2021 get_country lab = {resolved_label}")
                return resolved_label
        return ""

    def get_term_label(
        self, term_lower: str, separator: str, lab_type: str = "", start_get_country2: bool = True
    ) -> str:
        """Retrieve the corresponding label for a given term."""
        logger.info(f'get_term_label {lab_type=}, {separator=}, c_ct_lower:"{term_lower}" ')

        if app_settings.makeerr:
            start_get_country2 = True

        # Check for numeric/empty terms
        test_numeric = re.sub(r"\d+", "", term_lower.strip())
        if test_numeric in ["", "-", "–", "−"]:
            return term_lower

        term_label = New_female_keys.get(term_lower, "") or religious_entries.get(term_lower, "")
        if not term_label:
            term_label = convert_time_to_arabic(term_lower)

        if term_label == "" and lab_type != "type_label":
            if term_lower.startswith("the "):
                logger.info(f'>>>> {term_lower=} startswith("the ")')
                term_without_the = term_lower[len("the ") :]
                term_label = get_pop_All_18(term_without_the, "")
                if not term_label:
                    term_label = self.get_country_label(term_without_the, start_get_country2=start_get_country2)

        if not term_label:
            if re.sub(r"\d+", "", term_lower) == "":
                term_label = term_lower
            else:
                term_label = convert_time_to_arabic(term_lower)

        if term_label == "":
            term_label = self.get_country_label(term_lower, start_get_country2=start_get_country2)

        if not term_label and lab_type == "type_label":
            term_label = self._handle_type_lab_logic(term_lower, separator, start_get_country2)

        if term_label:
            logger.info(f"get_term_label {term_label=} ")
        elif separator.strip() == "for" and term_lower.startswith("for "):
            return self.get_term_label(term_lower[len("for ") :], "", lab_type=lab_type)

        return term_label

    def _handle_type_lab_logic(self, term_lower: str, separator: str, start_get_country2: bool) -> str:
        """Handle logic specific to type_label."""
        suffixes = [" of", " in", " at"]
        term_label = ""

        for suffix in suffixes:
            if not term_lower.endswith(suffix):
                continue

            base_term = term_lower[: -len(suffix)]
            translated_base = jobs_mens_data.get(base_term, "")

            logger.info(f" {base_term=}, {translated_base=}, {term_lower=} ")

            if term_label == "" and translated_base:
                term_label = f"{translated_base} من "
                logger.info(f"jobs_mens_data:: add من to {term_label=}, line:1583.")

            if not translated_base:
                translated_base = get_pop_All_18(base_term, "")

            if not translated_base:
                translated_base = self.get_country_label(base_term, start_get_country2=start_get_country2)

            if term_label == "" and translated_base:
                if term_lower in pop_of_without_in:
                    term_label = translated_base
                    logger.info("skip add في to pop_of_without_in")
                else:
                    term_label = f"{translated_base} في "
                    logger.info(f"XX add في to {term_label=}, line:1596.")
                return term_label  # Return immediately if found

        if term_label == "" and separator.strip() == "in":
            term_label = get_pop_All_18(f"{term_lower} in", "")

        if not term_label:
            term_label = self.get_country_label(term_lower, start_get_country2=start_get_country2)

        return term_label


# Instantiate the retriever
_retriever = CountryLabelRetriever()


def event2_d2(category_r) -> str:
    """
    Determine the category label based on the input string.
    """
    cat3 = category_r.lower().replace("category:", "").strip()

    logger.info(f'<<lightred>>>>>> category33:"{cat3}" ')

    # TODO: THIS NEED REVIEW
    # Reject strings that contain common English prepositions
    blocked = ("in", "of", "from", "by", "at")
    if any(f" {word} " in cat3.lower() for word in blocked):
        return ""

    category_lab = ""
    if re.sub(r"^\d", "", cat3) == cat3:
        category_lab = get_country(cat3)

    return category_lab


def get_country(country: str, start_get_country2: bool = True) -> str:
    """Retrieve the label for a given country name."""
    return _retriever.get_country_label(country, start_get_country2)


def Get_c_t_lab(term_lower: str, separator: str, lab_type: str = "", start_get_country2: bool = True) -> str:
    """Retrieve the corresponding label for a given country or term."""
    return _retriever.get_term_label(term_lower, separator, lab_type=lab_type, start_get_country2=start_get_country2)


__all__ = [
    "Get_c_t_lab",
    "get_country",
]



#!/usr/bin/python3
"""

TODO:
    - use this file instead of film_keys_bot.py
    - add formated_data from ArWikiCats/translations/tv/films_mslslat.py

"""

import functools
from typing import Dict

from ...helps import logger
from ...translations import (  # film_keys_for_female,
    Nat_women,
)
from ...translations_formats import MultiDataFormatterBase, format_films_country_data, format_multi_data

film_keys_for_female = {
    "3d": "ثلاثية الأبعاد",
    "4d": "رباعية الأبعاد",
    "action": "حركة",
    "action comedy": "حركة كوميدية",
    "action thriller": "إثارة حركة",
    "adaptation": "مقتبسة",
    "adult animated": "رسوم متحركة للكبار",
    "adult animated drama": "رسوم متحركة دراما للكبار",
    "adult animated supernatural": "رسوم متحركة خارقة للطبيعة للكبار",
    "adventure": "مغامرات",
    "animated": "رسوم متحركة",
    "animated science": "علمية رسوم متحركة",
    "animated short film": "رسوم متحركة قصيرة",
    "animated short": "رسوم متحركة قصيرة",
    "animation": "رسوم متحركة",
    "anime": "أنمي",
    "anthology": "أنثولوجيا",
    "apocalyptic": "نهاية العالم",
    "astronomical": "فلكية",
    "aviation": "طيران",
    "b movie": "درجة ثانية",
    "biographical": "سير ذاتية",
    "black": "سوداء",
    "black and white": "أبيض وأسود",
    "black comedy": "كوميدية سوداء",
    "black-and-white": "أبيض وأسود",
    "bollywood": "بوليوود",
    "buddy": "رفقاء",
    "cancelled": "ملغية",
    "cannibal": "آكلو لحم البشر",
    "chase": "مطاردة",
    "children's": "أطفال",
    "children's animated": "رسوم متحركة أطفال",
    "children's comedy": "أطفال كوميدية",
    "christmas": "عيد الميلاد",
    "colonial cinema": "استعمار",
    "comedy": "كوميدية",
    "comedy drama": "كوميدية درامية",
    "comedy fiction": "كوميدية خيالية",
    "comedy horror": "كوميدية رعب",
    "comedy thriller": "كوميدية إثارة",
    "comedy-drama": "كوميدية درامية",
    "comic science fiction": "خيالية علمية كوميدية",
    "coming-of-age": "تقدم في العمر",
    "coming-of-age story": "قصة تقدم في العمر",
    "computer animated": "حركة حاسوبية",
    "computer-animated": "حركة حاسوبية",
    "crime": "جريمة",
    "crime comedy": "جنائية كوميدية",
    "crime thriller": "إثارة وجريمة",
    "crime-comedy": "جنائية كوميدية",
    "criminal": "جنائية",
    "criminal comedy": "كوميديا الجريمة",
    "cyberpunk": "سايبربانك",
    "dance": "رقص",
    "dark fantasy": "فانتازيا مظلمة",
    "detective": "مباحث",
    "detective fiction": "خيالية بوليسية",
    "disaster": "كوارثية",
    "disney animated": "رسوم متحركة ديزني",
    "docudrama": "درامية وثائقية",
    "documentary": "وثائقية",
    "drama": "درامية",
    "educational": "تعليمية",
    "environment": "بيئية",
    "epic": "ملحمية",
    "erotic": "إغرائية",
    "erotic thriller": "إثارة جنسية",
    "european art cinema": "السينما الفنية الأوروبية",
    "experimental": "تجريبية",
    "exploitation": "استغلالية",
    "family": "عائلية",
    "fan": "معجبين",
    "fantasy": "فانتازيا",
    "feature": "طويلة",
    "female buddy": "رفيقات",
    "feminist": "نسوية",
    "fiction": "خيالية",
    "final fantasy": "فاينل فانتازي",
    "flashback": "استرجاع",
    "found footage": "تسجيلات مكتشفة",
    "free cinema": "سينما حرة",
    "gangster": "عصابات",
    "girls with guns": "فتيات مع أسلحة",
    "hacking": "إختراق",
    "heist": "سرقة",
    "historical": "تاريخية",
    "holocaust": "هولوكوستية",
    "hood": "هود",
    "horror": "رعب",
    "independent": "مستقلة",
    "interactive": "تفاعلية",
    "internet": "إنترنت",
    "japanese horror": "رعب يابانية",
    "joker": "جوكر",
    "kaiju": "كايجو",
    "kung fu": "كونغ فو",
    "latin": "لاتينية",
    "legal": "قانونية",
    "legal drama": "دراما قانونية",
    "legal thriller": "إثارة قانونية",
    "lgbt": "إل جي بي تي",
    "lgbtq": "إل جي بي تي كيو",
    "lgbtq-related": "متعلقة بإل جي بي تي كيو",
    "live": "مباشرة",
    "live-action": "حركة مباشرة",
    "lost": "مفقودة",
    "low-budget": "منخفضة التكلفة",
    "mafia": "مافيا",
    "magic realism": "واقعية سحرية",
    "magical girl": "فتاة ساحرة",
    "maritime": "بحرية",
    "martial arts": "فنون قتال",
    "melodrama": "ميلودراما",
    "metafictional": "ما وراء القص",
    "military": "عسكرية",
    "mixtape": "ميكستايب",
    "mockumentary": "وثائقية كاذبة",
    "monster": "وحوش",
    "music": "موسيقية",
    "musical": "موسيقية",
    "musical comedy": "كوميدية موسيقية",
    "mystery": "غموض",
    "nature documentary": "وثائقية برية",
    "nautical": "بحرية",
    "naval": "بحرية عسكرية",
    "neo-noir": "نيو-نوار",
    "noir": "نوار",
    "non fiction": "غير خيالية",
    "non narrative": "غير سردية",
    "non-fiction": "غير خيالية",
    "non-narrative": "غير سردية",
    "one man": "رجل واحد",
    "one-man": "رجل واحد",
    "parody": "ساخرة",
    "period": "حقبية",
    "pirate": "قراصنة",
    "police procedural": "إجراءات الشرطة",
    "political": "سياسية",
    "political cinema": "سينما سياسية",
    "political fiction": "خيالية سياسية",
    "political thriller": "إثارة سياسية",
    "porno": "إباحية",
    "pornographic": "إباحية",
    "post-apocalyptic": "ما بعد الكارثة",
    "prequel": "بادئة",
    "propaganda": "دعائية",
    "psychological": "نفسية",
    "psychological horror": "رعب نفسي",
    "psychological thriller": "إثارة نفسية",
    "reality": "واقعية",
    "reboot": "ريبوت",
    "rediscovered": "اكتشاف",
    "religious": "دينية",
    "remix": "ريمكس",
    "reportage": "تقرير",
    "robot": "آلية",
    "rockumentary": "وثائقي الروك",
    "romance": "رومانسية",
    "romantic": "رومانسية",
    "romantic comedy": "كوميدية رومانسية",
    "sailing": "إبحار",
    "samurai cinema": "ساموراي",
    "satire": "هجائية",
    "school": "مدرسية",
    "science": "علمية",
    "science fantasy": "فنتازيا علمية",
    "science fiction": "خيال علمي",
    "science fiction action": "خيال علمي وحركة",
    "science fiction thriller": "إثارة خيال علمي",
    "sequel": "متممة",
    "sex": "جنسية",
    "short": "قصيرة",
    "siddy": "أصدقاء",
    "silent": "صامتة",
    "silent short": "قصيرة صامته",
    "sisiness": "أعمال",
    "slapstick": "كوميدية تهريجية",
    "slasher": "تقطيع",
    "sound": "ناطقة",
    "spaghetti western": "سباغيتي وسترن",
    "speculative": "تأملية",
    "speculative fiction": "خيالية تأملية",
    "sports": "رياضية",
    "spy": "تجسسية",
    "street fighter": "قتال شوارع",
    "student": "طلاب",
    "submarines": "غواصات",
    "super robot": "آلية خارقة",
    "supernatural": "خارقة للطبيعة",
    "supernatural drama": "دراما خارقة للطبيعة",
    "survival": "البقاء على قيد الحياة",
    "teen": "مراهقة",
    "television": "تلفزيونية",
    "thriller": "إثارة",
    "tragicomedy": "تراجيدية كوميدية",
    "travel documentary": "وثائقي سفر",
    "treasure hunt": "صيد كنوز",
    "unfinished": "ناقصة",
    "upcoming": "قادمة",
    "vampire": "مصاصي دماء",
    "war": "حربية",
    "werewolve": "مستذئب",
    "western": "غرب أمريكية",
    "woman's": "نسائية",
    "zombie": "زومبي",
    "zombie comedy": "كوميدية الزومبي",
}


def _build_television_cao() -> tuple[Dict[str, str], Dict[str, str]]:
    """
    Build translation mappings for CAO-related film and television keys.

    Creates two dictionaries: one containing patterns that include nationality placeholders and film-key placeholders for generating localized Arabic labels, and another containing equivalent mappings that omit nationality placeholders.

    Returns:
        films_key_cao (dict): Mapping of English pattern keys (may include `{nat_en}` and `{film_key}`) to Arabic translation templates (may include `{nat_ar}` and `{film_ar}`).
        data_no_nats (dict): Mapping of English pattern keys (without nationality placeholders) to Arabic translation templates (may include `{film_ar}`).
    """
    data = {}
    data_no_nats = {}

    # Base TV keys with common suffixes
    for suffix, arabic_suffix in [
        ("characters", "شخصيات"),
        ("title cards", "بطاقات عنوان"),
        ("video covers", "أغلفة فيديو"),
        ("posters", "ملصقات"),
        ("images", "صور"),
    ]:
        data_no_nats.update(
            {
                f"{{film_key}} {suffix}": f"{arabic_suffix} {{film_ar}}",
            }
        )
        data.update(
            {
                f"{{nat_en}} {suffix}": f"{arabic_suffix} {{nat_ar}}",
                f"{{nat_en}} {{film_key}} {suffix}": f"{arabic_suffix} {{film_ar}} {{nat_ar}}",
            }
        )

    # Genre-based categories
    # ArWikiCats/jsons/media/Films_key_For_nat.json
    genre_categories = {
        # "fiction": "خيال",
        "film series": "سلاسل أفلام",
        "webcomics": "ويب كومكس",
        "anime and manga": "أنمي ومانغا",
        "compilation albums": "ألبومات تجميعية",
        "folk albums": "ألبومات فلكلورية",
        "classical albums": "ألبومات كلاسيكية",
        "comedy albums": "ألبومات كوميدية",
        "mixtape albums": "ألبومات ميكستايب",
        "soundtracks": "موسيقى تصويرية",
        "terminology": "مصطلحات",
        "series": "مسلسلات",
        "television series": "مسلسلات تلفزيونية",
        "television episodes": "حلقات تلفزيونية",
        "television programs": "برامج تلفزيونية",
        "television programmes": "برامج تلفزيونية",
        "groups": "مجموعات",
        "novellas": "روايات قصيرة",
        "novels": "روايات",
        "films": "أفلام",
        "comic strips": "شرائط كومكس",
        "comics": "قصص مصورة",
        "television shows": "عروض تلفزيونية",
        "television films": "أفلام تلفزيونية",
        "teams": "فرق",
        "television characters": "شخصيات تلفزيونية",
        "video games": "ألعاب فيديو",
        "web series": "مسلسلات ويب",
        "film characters": "شخصيات أفلام",
        "games": "ألعاب",
        "soap opera": "مسلسلات طويلة",
        "television news": "أخبار تلفزيونية",
        "miniseries": "مسلسلات قصيرة",
        "television miniseries": "مسلسلات قصيرة تلفزيونية",
    }

    genre_categories_skip_it = {
        "film characters",
        "series",
        "games",
    }

    # Standard categories
    for suffix, arabic_base in genre_categories.items():
        # Base TV keys with common suffixes
        for sub_suffix, arabic_sub_suffix in [
            ("characters", "شخصيات"),
            ("title cards", "بطاقات عنوان"),
            ("video covers", "أغلفة فيديو"),
            ("posters", "ملصقات"),
            ("images", "صور"),
        ]:
            data_no_nats.update(
                {
                    f"{suffix} {sub_suffix}": f"{arabic_sub_suffix} {arabic_base}",
                    f"{{film_key}} {suffix} {sub_suffix}": f"{arabic_sub_suffix} {arabic_base} {{film_ar}}",
                }
            )
            data.update(
                {
                    f"{{nat_en}} {suffix} {sub_suffix}": f"{arabic_sub_suffix} {arabic_base} {{nat_ar}}",
                    f"{{nat_en}} {{film_key}} {suffix} {sub_suffix}": f"{arabic_sub_suffix} {arabic_base} {{film_ar}} {{nat_ar}}",
                }
            )

        data_no_nats.update(
            {
                f"{suffix}": f"{arabic_base}",
                f"television {suffix}": f"{arabic_base} تلفزيونية",
                f"{{film_key}} {suffix}": f"{arabic_base} {{film_ar}}",
                f"children's-animated-superhero {suffix}": f"{arabic_base} رسوم متحركة أبطال خارقين للأطفال",
                f"children's-animated-adventure-television {suffix}": f"{arabic_base} مغامرات رسوم متحركة تلفزيونية للأطفال",
            }
        )

        # NOTE: we use genre_categories_skip_it because next line makes errors like:
        # "Category:Golf at 2022 Asian Games": "تصنيف:الغولف في ألعاب آسيوية في 2022",
        if suffix not in genre_categories_skip_it:
            data[f"{{nat_en}} {suffix}"] = f"{arabic_base} {{nat_ar}}"

        data.update(
            {
                f"{{nat_en}} {{film_key}} {suffix}": f"{arabic_base} {{film_ar}} {{nat_ar}}",
                f"{{nat_en}} children's-animated-superhero {suffix}": f"{arabic_base} رسوم متحركة أبطال خارقين {{nat_ar}} للأطفال",
                f"{{nat_en}} children's-animated-adventure-television {suffix}": f"{arabic_base} مغامرات رسوم متحركة تلفزيونية {{nat_ar}} للأطفال",
            }
        )

    return data, data_no_nats


@functools.lru_cache(maxsize=1)
def _make_bot() -> MultiDataFormatterBase:
    # NOTE: keys with non-patterns should be added to populate_film_patterns()
    # Template data with both nationality and sport placeholders
    """
    Create and configure formatter bots for film and television category translations.

    Builds and merges formatted pattern data (including television CAO entries and film-key mappings),
    prepares nationality and film-key lookup lists, and generates two formatter instances:
    - `double_bot`: a combined formatter populated with country+film patterns and additional adjustments.
    - `bot`: a multi-data formatter built from the same inputs.

    This function also updates `double_bot.other_bot` to set the `put_label_last` label ordering.

    Returns:
        tuple: `(double_bot, bot)` where `double_bot` is the combined MultiDataFormatterBase with populated film-country patterns and `bot` is an additional MultiDataFormatterBase built from the same formatted data.
    """
    formatted_data = {
        # "{nat_en} films": "أفلام {nat_ar}", #  [2000s American films] : "تصنيف:أفلام أمريكية في عقد 2000",
        "{nat_en} films": "أفلام {nat_ar}",
        # "Category:yemeni action Teen superhero films" : "تصنيف:أفلام حركة مراهقة يمنية أبطال خارقين",
        "{nat_en} television episodes": "حلقات تلفزيونية {nat_ar}",
        "{nat_en} television series": "مسلسلات تلفزيونية {nat_ar}",
        "{nat_en} television-seasons": "مواسم تلفزيونية {nat_ar}",
        "{nat_en} television seasons": "مواسم تلفزيونية {nat_ar}",
        "{nat_en} {film_key} television-seasons": "مواسم تلفزيونية {film_ar} {nat_ar}",
        "{nat_en} {film_key} television seasons": "مواسم تلفزيونية {film_ar} {nat_ar}",
        "{nat_en} {film_key} television series": "مسلسلات تلفزيونية {film_ar} {nat_ar}",
        "{nat_en} {film_key} filmszz": "أفلام {film_ar} {nat_ar}",
        "{nat_en} {film_key} films": "أفلام {film_ar} {nat_ar}",
        "{nat_en} {film_key} television commercials": "إعلانات تجارية تلفزيونية {film_ar} {nat_ar}",
        # TODO: move this to jobs bot?
        # "{nat_en} sports coaches": "مدربو رياضة {nat_ar}",
        "{nat_en} animated television films": "أفلام رسوم متحركة تلفزيونية {nat_ar}",
        "{nat_en} animated television series": "مسلسلات رسوم متحركة تلفزيونية {nat_ar}",
    }

    _data, data_no_nats = _build_television_cao()

    formatted_data.update(_data)

    other_formatted_data = {
        "{film_key} films": "أفلام {film_ar}",
        # "Category:action Teen superhero films" : "تصنيف:أفلام حركة مراهقة أبطال خارقين",
        "{film_key} television commercials": "إعلانات تجارية تلفزيونية {film_ar}",
        "animated television films": "أفلام رسوم متحركة تلفزيونية",
        "animated television series": "مسلسلات رسوم متحركة تلفزيونية",
    }
    other_formatted_data.update(data_no_nats)

    # film_keys_for_female
    data_list2 = {
        "action comedy": "حركة كوميدية",
        "action thriller": "إثارة حركة",
        "action": "حركة",
        "drama": "درامية",
        "upcoming": "قادمة",
        "horror": "رعب",
        "black-and-white": "أبيض وأسود",
        "psychological horror": "رعب نفسي",
    }

    put_label_last = {
        "low-budget",
        "supernatural",
        "christmas",
        "lgbtq-related",
        "upcoming",
    }

    data_list2 = dict(film_keys_for_female)
    data_list2.pop("television", None)

    # data_list2.pop("superhero", None)
    data_list2["superhero"] = "أبطال خارقين"

    double_bot = format_films_country_data(
        formatted_data=formatted_data,
        data_list=Nat_women,
        key_placeholder="{nat_en}",
        value_placeholder="{nat_ar}",
        data_list2=data_list2,
        key2_placeholder="{film_key}",
        value2_placeholder="{film_ar}",
        text_after="",
        text_before="",
        other_formatted_data=other_formatted_data,
    )

    double_bot.other_bot.update_put_label_last(put_label_last)
    bot = format_multi_data(
        formatted_data=formatted_data,
        data_list=Nat_women,
        key_placeholder="{nat_en}",
        value_placeholder="{nat_ar}",
        data_list2=data_list2,
        key2_placeholder="{film_key}",
        value2_placeholder="{film_ar}",
        text_after="",
        text_before="",
        other_formatted_data=other_formatted_data,
    )
    return double_bot, bot


def fix_keys(category: str) -> str:
    """Fix known issues in category keys."""
    normalized_text = category.lower().replace("category:", " ").strip()
    fixes = {
        "saudi arabian": "saudiarabian",
        # "animated television": "animated-television",
        "children's animated adventure television": "children's-animated-adventure-television",
        "children's animated superhero": "children's-animated-superhero",
    }
    category = category.lower().strip()

    for old, new in fixes.items():
        category = category.replace(old, new)

    return category


@functools.lru_cache(maxsize=None)
def _get_films_key_tyty_new(text: str) -> str:
    """
    Function to generate a films key based on the country identifier.
    Args:
        text (str): The country identifier string to process.
    Returns:
        str: The resolved label string, or empty string if no match is found.
    """
    normalized_text = fix_keys(text)
    logger.debug(f"<<yellow>> start get_films_key_tyty_new: {normalized_text=}")
    double_bot, bot = _make_bot()

    result = bot.search_all(normalized_text) or double_bot.search_all(normalized_text)
    logger.info_if_or_debug(f"<<yellow>> end get_films_key_tyty_new: {normalized_text=}, {result=}", result)
    return result


@functools.lru_cache(maxsize=None)
def get_films_key_tyty_new(text: str) -> str:
    """
    Function to generate a films key based on the country identifier.
    Args:
        text (str): The country identifier string to process.
    Returns:
        str: The resolved label string, or empty string if no match is found.
    """
    # return ""
    return _get_films_key_tyty_new(text)
